// This is auto-gen data for Capstone engine (www.capstone-engine.org)
// By Nguyen Anh Quynh <aquynh@gmail.com>

	{ SYSZ_INS_A, "a" },
	{ SYSZ_INS_ADB, "adb" },
	{ SYSZ_INS_ADBR, "adbr" },
	{ SYSZ_INS_AEB, "aeb" },
	{ SYSZ_INS_AEBR, "aebr" },
	{ SYSZ_INS_AFI, "afi" },
	{ SYSZ_INS_AG, "ag" },
	{ SYSZ_INS_AGF, "agf" },
	{ SYSZ_INS_AGFI, "agfi" },
	{ SYSZ_INS_AGFR, "agfr" },
	{ SYSZ_INS_AGHI, "aghi" },
	{ SYSZ_INS_AGHIK, "aghik" },
	{ SYSZ_INS_AGR, "agr" },
	{ SYSZ_INS_AGRK, "agrk" },
	{ SYSZ_INS_AGSI, "agsi" },
	{ SYSZ_INS_AH, "ah" },
	{ SYSZ_INS_AHI, "ahi" },
	{ SYSZ_INS_AHIK, "ahik" },
	{ SYSZ_INS_AHY, "ahy" },
	{ SYSZ_INS_AIH, "aih" },
	{ SYSZ_INS_AL, "al" },
	{ SYSZ_INS_ALC, "alc" },
	{ SYSZ_INS_ALCG, "alcg" },
	{ SYSZ_INS_ALCGR, "alcgr" },
	{ SYSZ_INS_ALCR, "alcr" },
	{ SYSZ_INS_ALFI, "alfi" },
	{ SYSZ_INS_ALG, "alg" },
	{ SYSZ_INS_ALGF, "algf" },
	{ SYSZ_INS_ALGFI, "algfi" },
	{ SYSZ_INS_ALGFR, "algfr" },
	{ SYSZ_INS_ALGHSIK, "alghsik" },
	{ SYSZ_INS_ALGR, "algr" },
	{ SYSZ_INS_ALGRK, "algrk" },
	{ SYSZ_INS_ALHSIK, "alhsik" },
	{ SYSZ_INS_ALR, "alr" },
	{ SYSZ_INS_ALRK, "alrk" },
	{ SYSZ_INS_ALY, "aly" },
	{ SYSZ_INS_AR, "ar" },
	{ SYSZ_INS_ARK, "ark" },
	{ SYSZ_INS_ASI, "asi" },
	{ SYSZ_INS_AXBR, "axbr" },
	{ SYSZ_INS_AY, "ay" },
	{ SYSZ_INS_BCR, "bcr" },
	{ SYSZ_INS_BRC, "brc" },
	{ SYSZ_INS_BRCL, "brcl" },
	{ SYSZ_INS_CGIJ, "cgij" },
	{ SYSZ_INS_CGRJ, "cgrj" },
	{ SYSZ_INS_CIJ, "cij" },
	{ SYSZ_INS_CLGIJ, "clgij" },
	{ SYSZ_INS_CLGRJ, "clgrj" },
	{ SYSZ_INS_CLIJ, "clij" },
	{ SYSZ_INS_CLRJ, "clrj" },
	{ SYSZ_INS_CRJ, "crj" },
	{ SYSZ_INS_BER, "ber" },
	{ SYSZ_INS_JE, "je" },
	{ SYSZ_INS_JGE, "jge" },
	{ SYSZ_INS_LOCE, "loce" },
	{ SYSZ_INS_LOCGE, "locge" },
	{ SYSZ_INS_LOCGRE, "locgre" },
	{ SYSZ_INS_LOCRE, "locre" },
	{ SYSZ_INS_STOCE, "stoce" },
	{ SYSZ_INS_STOCGE, "stocge" },
	{ SYSZ_INS_BHR, "bhr" },
	{ SYSZ_INS_BHER, "bher" },
	{ SYSZ_INS_JHE, "jhe" },
	{ SYSZ_INS_JGHE, "jghe" },
	{ SYSZ_INS_LOCHE, "loche" },
	{ SYSZ_INS_LOCGHE, "locghe" },
	{ SYSZ_INS_LOCGRHE, "locgrhe" },
	{ SYSZ_INS_LOCRHE, "locrhe" },
	{ SYSZ_INS_STOCHE, "stoche" },
	{ SYSZ_INS_STOCGHE, "stocghe" },
	{ SYSZ_INS_JH, "jh" },
	{ SYSZ_INS_JGH, "jgh" },
	{ SYSZ_INS_LOCH, "loch" },
	{ SYSZ_INS_LOCGH, "locgh" },
	{ SYSZ_INS_LOCGRH, "locgrh" },
	{ SYSZ_INS_LOCRH, "locrh" },
	{ SYSZ_INS_STOCH, "stoch" },
	{ SYSZ_INS_STOCGH, "stocgh" },
	{ SYSZ_INS_CGIJNLH, "cgijnlh" },
	{ SYSZ_INS_CGRJNLH, "cgrjnlh" },
	{ SYSZ_INS_CIJNLH, "cijnlh" },
	{ SYSZ_INS_CLGIJNLH, "clgijnlh" },
	{ SYSZ_INS_CLGRJNLH, "clgrjnlh" },
	{ SYSZ_INS_CLIJNLH, "clijnlh" },
	{ SYSZ_INS_CLRJNLH, "clrjnlh" },
	{ SYSZ_INS_CRJNLH, "crjnlh" },
	{ SYSZ_INS_CGIJE, "cgije" },
	{ SYSZ_INS_CGRJE, "cgrje" },
	{ SYSZ_INS_CIJE, "cije" },
	{ SYSZ_INS_CLGIJE, "clgije" },
	{ SYSZ_INS_CLGRJE, "clgrje" },
	{ SYSZ_INS_CLIJE, "clije" },
	{ SYSZ_INS_CLRJE, "clrje" },
	{ SYSZ_INS_CRJE, "crje" },
	{ SYSZ_INS_CGIJNLE, "cgijnle" },
	{ SYSZ_INS_CGRJNLE, "cgrjnle" },
	{ SYSZ_INS_CIJNLE, "cijnle" },
	{ SYSZ_INS_CLGIJNLE, "clgijnle" },
	{ SYSZ_INS_CLGRJNLE, "clgrjnle" },
	{ SYSZ_INS_CLIJNLE, "clijnle" },
	{ SYSZ_INS_CLRJNLE, "clrjnle" },
	{ SYSZ_INS_CRJNLE, "crjnle" },
	{ SYSZ_INS_CGIJH, "cgijh" },
	{ SYSZ_INS_CGRJH, "cgrjh" },
	{ SYSZ_INS_CIJH, "cijh" },
	{ SYSZ_INS_CLGIJH, "clgijh" },
	{ SYSZ_INS_CLGRJH, "clgrjh" },
	{ SYSZ_INS_CLIJH, "clijh" },
	{ SYSZ_INS_CLRJH, "clrjh" },
	{ SYSZ_INS_CRJH, "crjh" },
	{ SYSZ_INS_CGIJNL, "cgijnl" },
	{ SYSZ_INS_CGRJNL, "cgrjnl" },
	{ SYSZ_INS_CIJNL, "cijnl" },
	{ SYSZ_INS_CLGIJNL, "clgijnl" },
	{ SYSZ_INS_CLGRJNL, "clgrjnl" },
	{ SYSZ_INS_CLIJNL, "clijnl" },
	{ SYSZ_INS_CLRJNL, "clrjnl" },
	{ SYSZ_INS_CRJNL, "crjnl" },
	{ SYSZ_INS_CGIJHE, "cgijhe" },
	{ SYSZ_INS_CGRJHE, "cgrjhe" },
	{ SYSZ_INS_CIJHE, "cijhe" },
	{ SYSZ_INS_CLGIJHE, "clgijhe" },
	{ SYSZ_INS_CLGRJHE, "clgrjhe" },
	{ SYSZ_INS_CLIJHE, "clijhe" },
	{ SYSZ_INS_CLRJHE, "clrjhe" },
	{ SYSZ_INS_CRJHE, "crjhe" },
	{ SYSZ_INS_CGIJNHE, "cgijnhe" },
	{ SYSZ_INS_CGRJNHE, "cgrjnhe" },
	{ SYSZ_INS_CIJNHE, "cijnhe" },
	{ SYSZ_INS_CLGIJNHE, "clgijnhe" },
	{ SYSZ_INS_CLGRJNHE, "clgrjnhe" },
	{ SYSZ_INS_CLIJNHE, "clijnhe" },
	{ SYSZ_INS_CLRJNHE, "clrjnhe" },
	{ SYSZ_INS_CRJNHE, "crjnhe" },
	{ SYSZ_INS_CGIJL, "cgijl" },
	{ SYSZ_INS_CGRJL, "cgrjl" },
	{ SYSZ_INS_CIJL, "cijl" },
	{ SYSZ_INS_CLGIJL, "clgijl" },
	{ SYSZ_INS_CLGRJL, "clgrjl" },
	{ SYSZ_INS_CLIJL, "clijl" },
	{ SYSZ_INS_CLRJL, "clrjl" },
	{ SYSZ_INS_CRJL, "crjl" },
	{ SYSZ_INS_CGIJNH, "cgijnh" },
	{ SYSZ_INS_CGRJNH, "cgrjnh" },
	{ SYSZ_INS_CIJNH, "cijnh" },
	{ SYSZ_INS_CLGIJNH, "clgijnh" },
	{ SYSZ_INS_CLGRJNH, "clgrjnh" },
	{ SYSZ_INS_CLIJNH, "clijnh" },
	{ SYSZ_INS_CLRJNH, "clrjnh" },
	{ SYSZ_INS_CRJNH, "crjnh" },
	{ SYSZ_INS_CGIJLE, "cgijle" },
	{ SYSZ_INS_CGRJLE, "cgrjle" },
	{ SYSZ_INS_CIJLE, "cijle" },
	{ SYSZ_INS_CLGIJLE, "clgijle" },
	{ SYSZ_INS_CLGRJLE, "clgrjle" },
	{ SYSZ_INS_CLIJLE, "clijle" },
	{ SYSZ_INS_CLRJLE, "clrjle" },
	{ SYSZ_INS_CRJLE, "crjle" },
	{ SYSZ_INS_CGIJNE, "cgijne" },
	{ SYSZ_INS_CGRJNE, "cgrjne" },
	{ SYSZ_INS_CIJNE, "cijne" },
	{ SYSZ_INS_CLGIJNE, "clgijne" },
	{ SYSZ_INS_CLGRJNE, "clgrjne" },
	{ SYSZ_INS_CLIJNE, "clijne" },
	{ SYSZ_INS_CLRJNE, "clrjne" },
	{ SYSZ_INS_CRJNE, "crjne" },
	{ SYSZ_INS_CGIJLH, "cgijlh" },
	{ SYSZ_INS_CGRJLH, "cgrjlh" },
	{ SYSZ_INS_CIJLH, "cijlh" },
	{ SYSZ_INS_CLGIJLH, "clgijlh" },
	{ SYSZ_INS_CLGRJLH, "clgrjlh" },
	{ SYSZ_INS_CLIJLH, "clijlh" },
	{ SYSZ_INS_CLRJLH, "clrjlh" },
	{ SYSZ_INS_CRJLH, "crjlh" },
	{ SYSZ_INS_BLR, "blr" },
	{ SYSZ_INS_BLER, "bler" },
	{ SYSZ_INS_JLE, "jle" },
	{ SYSZ_INS_JGLE, "jgle" },
	{ SYSZ_INS_LOCLE, "locle" },
	{ SYSZ_INS_LOCGLE, "locgle" },
	{ SYSZ_INS_LOCGRLE, "locgrle" },
	{ SYSZ_INS_LOCRLE, "locrle" },
	{ SYSZ_INS_STOCLE, "stocle" },
	{ SYSZ_INS_STOCGLE, "stocgle" },
	{ SYSZ_INS_BLHR, "blhr" },
	{ SYSZ_INS_JLH, "jlh" },
	{ SYSZ_INS_JGLH, "jglh" },
	{ SYSZ_INS_LOCLH, "loclh" },
	{ SYSZ_INS_LOCGLH, "locglh" },
	{ SYSZ_INS_LOCGRLH, "locgrlh" },
	{ SYSZ_INS_LOCRLH, "locrlh" },
	{ SYSZ_INS_STOCLH, "stoclh" },
	{ SYSZ_INS_STOCGLH, "stocglh" },
	{ SYSZ_INS_JL, "jl" },
	{ SYSZ_INS_JGL, "jgl" },
	{ SYSZ_INS_LOCL, "locl" },
	{ SYSZ_INS_LOCGL, "locgl" },
	{ SYSZ_INS_LOCGRL, "locgrl" },
	{ SYSZ_INS_LOCRL, "locrl" },
	{ SYSZ_INS_LOC, "loc" },
	{ SYSZ_INS_LOCG, "locg" },
	{ SYSZ_INS_LOCGR, "locgr" },
	{ SYSZ_INS_LOCR, "locr" },
	{ SYSZ_INS_STOCL, "stocl" },
	{ SYSZ_INS_STOCGL, "stocgl" },
	{ SYSZ_INS_BNER, "bner" },
	{ SYSZ_INS_JNE, "jne" },
	{ SYSZ_INS_JGNE, "jgne" },
	{ SYSZ_INS_LOCNE, "locne" },
	{ SYSZ_INS_LOCGNE, "locgne" },
	{ SYSZ_INS_LOCGRNE, "locgrne" },
	{ SYSZ_INS_LOCRNE, "locrne" },
	{ SYSZ_INS_STOCNE, "stocne" },
	{ SYSZ_INS_STOCGNE, "stocgne" },
	{ SYSZ_INS_BNHR, "bnhr" },
	{ SYSZ_INS_BNHER, "bnher" },
	{ SYSZ_INS_JNHE, "jnhe" },
	{ SYSZ_INS_JGNHE, "jgnhe" },
	{ SYSZ_INS_LOCNHE, "locnhe" },
	{ SYSZ_INS_LOCGNHE, "locgnhe" },
	{ SYSZ_INS_LOCGRNHE, "locgrnhe" },
	{ SYSZ_INS_LOCRNHE, "locrnhe" },
	{ SYSZ_INS_STOCNHE, "stocnhe" },
	{ SYSZ_INS_STOCGNHE, "stocgnhe" },
	{ SYSZ_INS_JNH, "jnh" },
	{ SYSZ_INS_JGNH, "jgnh" },
	{ SYSZ_INS_LOCNH, "locnh" },
	{ SYSZ_INS_LOCGNH, "locgnh" },
	{ SYSZ_INS_LOCGRNH, "locgrnh" },
	{ SYSZ_INS_LOCRNH, "locrnh" },
	{ SYSZ_INS_STOCNH, "stocnh" },
	{ SYSZ_INS_STOCGNH, "stocgnh" },
	{ SYSZ_INS_BNLR, "bnlr" },
	{ SYSZ_INS_BNLER, "bnler" },
	{ SYSZ_INS_JNLE, "jnle" },
	{ SYSZ_INS_JGNLE, "jgnle" },
	{ SYSZ_INS_LOCNLE, "locnle" },
	{ SYSZ_INS_LOCGNLE, "locgnle" },
	{ SYSZ_INS_LOCGRNLE, "locgrnle" },
	{ SYSZ_INS_LOCRNLE, "locrnle" },
	{ SYSZ_INS_STOCNLE, "stocnle" },
	{ SYSZ_INS_STOCGNLE, "stocgnle" },
	{ SYSZ_INS_BNLHR, "bnlhr" },
	{ SYSZ_INS_JNLH, "jnlh" },
	{ SYSZ_INS_JGNLH, "jgnlh" },
	{ SYSZ_INS_LOCNLH, "locnlh" },
	{ SYSZ_INS_LOCGNLH, "locgnlh" },
	{ SYSZ_INS_LOCGRNLH, "locgrnlh" },
	{ SYSZ_INS_LOCRNLH, "locrnlh" },
	{ SYSZ_INS_STOCNLH, "stocnlh" },
	{ SYSZ_INS_STOCGNLH, "stocgnlh" },
	{ SYSZ_INS_JNL, "jnl" },
	{ SYSZ_INS_JGNL, "jgnl" },
	{ SYSZ_INS_LOCNL, "locnl" },
	{ SYSZ_INS_LOCGNL, "locgnl" },
	{ SYSZ_INS_LOCGRNL, "locgrnl" },
	{ SYSZ_INS_LOCRNL, "locrnl" },
	{ SYSZ_INS_STOCNL, "stocnl" },
	{ SYSZ_INS_STOCGNL, "stocgnl" },
	{ SYSZ_INS_BNOR, "bnor" },
	{ SYSZ_INS_JNO, "jno" },
	{ SYSZ_INS_JGNO, "jgno" },
	{ SYSZ_INS_LOCNO, "locno" },
	{ SYSZ_INS_LOCGNO, "locgno" },
	{ SYSZ_INS_LOCGRNO, "locgrno" },
	{ SYSZ_INS_LOCRNO, "locrno" },
	{ SYSZ_INS_STOCNO, "stocno" },
	{ SYSZ_INS_STOCGNO, "stocgno" },
	{ SYSZ_INS_BOR, "bor" },
	{ SYSZ_INS_JO, "jo" },
	{ SYSZ_INS_JGO, "jgo" },
	{ SYSZ_INS_LOCO, "loco" },
	{ SYSZ_INS_LOCGO, "locgo" },
	{ SYSZ_INS_LOCGRO, "locgro" },
	{ SYSZ_INS_LOCRO, "locro" },
	{ SYSZ_INS_STOCO, "stoco" },
	{ SYSZ_INS_STOCGO, "stocgo" },
	{ SYSZ_INS_STOC, "stoc" },
	{ SYSZ_INS_STOCG, "stocg" },
	{ SYSZ_INS_BASR, "basr" },
	{ SYSZ_INS_BR, "br" },
	{ SYSZ_INS_BRAS, "bras" },
	{ SYSZ_INS_BRASL, "brasl" },
	{ SYSZ_INS_J, "j" },
	{ SYSZ_INS_JG, "jg" },
	{ SYSZ_INS_BRCT, "brct" },
	{ SYSZ_INS_BRCTG, "brctg" },
	{ SYSZ_INS_C, "c" },
	{ SYSZ_INS_CDB, "cdb" },
	{ SYSZ_INS_CDBR, "cdbr" },
	{ SYSZ_INS_CDFBR, "cdfbr" },
	{ SYSZ_INS_CDGBR, "cdgbr" },
	{ SYSZ_INS_CDLFBR, "cdlfbr" },
	{ SYSZ_INS_CDLGBR, "cdlgbr" },
	{ SYSZ_INS_CEB, "ceb" },
	{ SYSZ_INS_CEBR, "cebr" },
	{ SYSZ_INS_CEFBR, "cefbr" },
	{ SYSZ_INS_CEGBR, "cegbr" },
	{ SYSZ_INS_CELFBR, "celfbr" },
	{ SYSZ_INS_CELGBR, "celgbr" },
	{ SYSZ_INS_CFDBR, "cfdbr" },
	{ SYSZ_INS_CFEBR, "cfebr" },
	{ SYSZ_INS_CFI, "cfi" },
	{ SYSZ_INS_CFXBR, "cfxbr" },
	{ SYSZ_INS_CG, "cg" },
	{ SYSZ_INS_CGDBR, "cgdbr" },
	{ SYSZ_INS_CGEBR, "cgebr" },
	{ SYSZ_INS_CGF, "cgf" },
	{ SYSZ_INS_CGFI, "cgfi" },
	{ SYSZ_INS_CGFR, "cgfr" },
	{ SYSZ_INS_CGFRL, "cgfrl" },
	{ SYSZ_INS_CGH, "cgh" },
	{ SYSZ_INS_CGHI, "cghi" },
	{ SYSZ_INS_CGHRL, "cghrl" },
	{ SYSZ_INS_CGHSI, "cghsi" },
	{ SYSZ_INS_CGR, "cgr" },
	{ SYSZ_INS_CGRL, "cgrl" },
	{ SYSZ_INS_CGXBR, "cgxbr" },
	{ SYSZ_INS_CH, "ch" },
	{ SYSZ_INS_CHF, "chf" },
	{ SYSZ_INS_CHHSI, "chhsi" },
	{ SYSZ_INS_CHI, "chi" },
	{ SYSZ_INS_CHRL, "chrl" },
	{ SYSZ_INS_CHSI, "chsi" },
	{ SYSZ_INS_CHY, "chy" },
	{ SYSZ_INS_CIH, "cih" },
	{ SYSZ_INS_CL, "cl" },
	{ SYSZ_INS_CLC, "clc" },
	{ SYSZ_INS_CLFDBR, "clfdbr" },
	{ SYSZ_INS_CLFEBR, "clfebr" },
	{ SYSZ_INS_CLFHSI, "clfhsi" },
	{ SYSZ_INS_CLFI, "clfi" },
	{ SYSZ_INS_CLFXBR, "clfxbr" },
	{ SYSZ_INS_CLG, "clg" },
	{ SYSZ_INS_CLGDBR, "clgdbr" },
	{ SYSZ_INS_CLGEBR, "clgebr" },
	{ SYSZ_INS_CLGF, "clgf" },
	{ SYSZ_INS_CLGFI, "clgfi" },
	{ SYSZ_INS_CLGFR, "clgfr" },
	{ SYSZ_INS_CLGFRL, "clgfrl" },
	{ SYSZ_INS_CLGHRL, "clghrl" },
	{ SYSZ_INS_CLGHSI, "clghsi" },
	{ SYSZ_INS_CLGR, "clgr" },
	{ SYSZ_INS_CLGRL, "clgrl" },
	{ SYSZ_INS_CLGXBR, "clgxbr" },
	{ SYSZ_INS_CLHF, "clhf" },
	{ SYSZ_INS_CLHHSI, "clhhsi" },
	{ SYSZ_INS_CLHRL, "clhrl" },
	{ SYSZ_INS_CLI, "cli" },
	{ SYSZ_INS_CLIH, "clih" },
	{ SYSZ_INS_CLIY, "cliy" },
	{ SYSZ_INS_CLR, "clr" },
	{ SYSZ_INS_CLRL, "clrl" },
	{ SYSZ_INS_CLST, "clst" },
	{ SYSZ_INS_CLY, "cly" },
	{ SYSZ_INS_CPSDR, "cpsdr" },
	{ SYSZ_INS_CR, "cr" },
	{ SYSZ_INS_CRL, "crl" },
	{ SYSZ_INS_CS, "cs" },
	{ SYSZ_INS_CSG, "csg" },
	{ SYSZ_INS_CSY, "csy" },
	{ SYSZ_INS_CXBR, "cxbr" },
	{ SYSZ_INS_CXFBR, "cxfbr" },
	{ SYSZ_INS_CXGBR, "cxgbr" },
	{ SYSZ_INS_CXLFBR, "cxlfbr" },
	{ SYSZ_INS_CXLGBR, "cxlgbr" },
	{ SYSZ_INS_CY, "cy" },
	{ SYSZ_INS_DDB, "ddb" },
	{ SYSZ_INS_DDBR, "ddbr" },
	{ SYSZ_INS_DEB, "deb" },
	{ SYSZ_INS_DEBR, "debr" },
	{ SYSZ_INS_DL, "dl" },
	{ SYSZ_INS_DLG, "dlg" },
	{ SYSZ_INS_DLGR, "dlgr" },
	{ SYSZ_INS_DLR, "dlr" },
	{ SYSZ_INS_DSG, "dsg" },
	{ SYSZ_INS_DSGF, "dsgf" },
	{ SYSZ_INS_DSGFR, "dsgfr" },
	{ SYSZ_INS_DSGR, "dsgr" },
	{ SYSZ_INS_DXBR, "dxbr" },
	{ SYSZ_INS_EAR, "ear" },
	{ SYSZ_INS_FIDBR, "fidbr" },
	{ SYSZ_INS_FIDBRA, "fidbra" },
	{ SYSZ_INS_FIEBR, "fiebr" },
	{ SYSZ_INS_FIEBRA, "fiebra" },
	{ SYSZ_INS_FIXBR, "fixbr" },
	{ SYSZ_INS_FIXBRA, "fixbra" },
	{ SYSZ_INS_FLOGR, "flogr" },
	{ SYSZ_INS_IC, "ic" },
	{ SYSZ_INS_ICY, "icy" },
	{ SYSZ_INS_IIHF, "iihf" },
	{ SYSZ_INS_IIHH, "iihh" },
	{ SYSZ_INS_IIHL, "iihl" },
	{ SYSZ_INS_IILF, "iilf" },
	{ SYSZ_INS_IILH, "iilh" },
	{ SYSZ_INS_IILL, "iill" },
	{ SYSZ_INS_IPM, "ipm" },
	{ SYSZ_INS_L, "l" },
	{ SYSZ_INS_LA, "la" },
	{ SYSZ_INS_LAA, "laa" },
	{ SYSZ_INS_LAAG, "laag" },
	{ SYSZ_INS_LAAL, "laal" },
	{ SYSZ_INS_LAALG, "laalg" },
	{ SYSZ_INS_LAN, "lan" },
	{ SYSZ_INS_LANG, "lang" },
	{ SYSZ_INS_LAO, "lao" },
	{ SYSZ_INS_LAOG, "laog" },
	{ SYSZ_INS_LARL, "larl" },
	{ SYSZ_INS_LAX, "lax" },
	{ SYSZ_INS_LAXG, "laxg" },
	{ SYSZ_INS_LAY, "lay" },
	{ SYSZ_INS_LB, "lb" },
	{ SYSZ_INS_LBH, "lbh" },
	{ SYSZ_INS_LBR, "lbr" },
	{ SYSZ_INS_LCDBR, "lcdbr" },
	{ SYSZ_INS_LCEBR, "lcebr" },
	{ SYSZ_INS_LCGFR, "lcgfr" },
	{ SYSZ_INS_LCGR, "lcgr" },
	{ SYSZ_INS_LCR, "lcr" },
	{ SYSZ_INS_LCXBR, "lcxbr" },
	{ SYSZ_INS_LD, "ld" },
	{ SYSZ_INS_LDEB, "ldeb" },
	{ SYSZ_INS_LDEBR, "ldebr" },
	{ SYSZ_INS_LDGR, "ldgr" },
	{ SYSZ_INS_LDR, "ldr" },
	{ SYSZ_INS_LDXBR, "ldxbr" },
	{ SYSZ_INS_LDXBRA, "ldxbra" },
	{ SYSZ_INS_LDY, "ldy" },
	{ SYSZ_INS_LE, "le" },
	{ SYSZ_INS_LEDBR, "ledbr" },
	{ SYSZ_INS_LEDBRA, "ledbra" },
	{ SYSZ_INS_LER, "ler" },
	{ SYSZ_INS_LEXBR, "lexbr" },
	{ SYSZ_INS_LEXBRA, "lexbra" },
	{ SYSZ_INS_LEY, "ley" },
	{ SYSZ_INS_LFH, "lfh" },
	{ SYSZ_INS_LG, "lg" },
	{ SYSZ_INS_LGB, "lgb" },
	{ SYSZ_INS_LGBR, "lgbr" },
	{ SYSZ_INS_LGDR, "lgdr" },
	{ SYSZ_INS_LGF, "lgf" },
	{ SYSZ_INS_LGFI, "lgfi" },
	{ SYSZ_INS_LGFR, "lgfr" },
	{ SYSZ_INS_LGFRL, "lgfrl" },
	{ SYSZ_INS_LGH, "lgh" },
	{ SYSZ_INS_LGHI, "lghi" },
	{ SYSZ_INS_LGHR, "lghr" },
	{ SYSZ_INS_LGHRL, "lghrl" },
	{ SYSZ_INS_LGR, "lgr" },
	{ SYSZ_INS_LGRL, "lgrl" },
	{ SYSZ_INS_LH, "lh" },
	{ SYSZ_INS_LHH, "lhh" },
	{ SYSZ_INS_LHI, "lhi" },
	{ SYSZ_INS_LHR, "lhr" },
	{ SYSZ_INS_LHRL, "lhrl" },
	{ SYSZ_INS_LHY, "lhy" },
	{ SYSZ_INS_LLC, "llc" },
	{ SYSZ_INS_LLCH, "llch" },
	{ SYSZ_INS_LLCR, "llcr" },
	{ SYSZ_INS_LLGC, "llgc" },
	{ SYSZ_INS_LLGCR, "llgcr" },
	{ SYSZ_INS_LLGF, "llgf" },
	{ SYSZ_INS_LLGFR, "llgfr" },
	{ SYSZ_INS_LLGFRL, "llgfrl" },
	{ SYSZ_INS_LLGH, "llgh" },
	{ SYSZ_INS_LLGHR, "llghr" },
	{ SYSZ_INS_LLGHRL, "llghrl" },
	{ SYSZ_INS_LLH, "llh" },
	{ SYSZ_INS_LLHH, "llhh" },
	{ SYSZ_INS_LLHR, "llhr" },
	{ SYSZ_INS_LLHRL, "llhrl" },
	{ SYSZ_INS_LLIHF, "llihf" },
	{ SYSZ_INS_LLIHH, "llihh" },
	{ SYSZ_INS_LLIHL, "llihl" },
	{ SYSZ_INS_LLILF, "llilf" },
	{ SYSZ_INS_LLILH, "llilh" },
	{ SYSZ_INS_LLILL, "llill" },
	{ SYSZ_INS_LMG, "lmg" },
	{ SYSZ_INS_LNDBR, "lndbr" },
	{ SYSZ_INS_LNEBR, "lnebr" },
	{ SYSZ_INS_LNGFR, "lngfr" },
	{ SYSZ_INS_LNGR, "lngr" },
	{ SYSZ_INS_LNR, "lnr" },
	{ SYSZ_INS_LNXBR, "lnxbr" },
	{ SYSZ_INS_LPDBR, "lpdbr" },
	{ SYSZ_INS_LPEBR, "lpebr" },
	{ SYSZ_INS_LPGFR, "lpgfr" },
	{ SYSZ_INS_LPGR, "lpgr" },
	{ SYSZ_INS_LPR, "lpr" },
	{ SYSZ_INS_LPXBR, "lpxbr" },
	{ SYSZ_INS_LR, "lr" },
	{ SYSZ_INS_LRL, "lrl" },
	{ SYSZ_INS_LRV, "lrv" },
	{ SYSZ_INS_LRVG, "lrvg" },
	{ SYSZ_INS_LRVGR, "lrvgr" },
	{ SYSZ_INS_LRVR, "lrvr" },
	{ SYSZ_INS_LT, "lt" },
	{ SYSZ_INS_LTDBR, "ltdbr" },
	{ SYSZ_INS_LTEBR, "ltebr" },
	{ SYSZ_INS_LTG, "ltg" },
	{ SYSZ_INS_LTGF, "ltgf" },
	{ SYSZ_INS_LTGFR, "ltgfr" },
	{ SYSZ_INS_LTGR, "ltgr" },
	{ SYSZ_INS_LTR, "ltr" },
	{ SYSZ_INS_LTXBR, "ltxbr" },
	{ SYSZ_INS_LXDB, "lxdb" },
	{ SYSZ_INS_LXDBR, "lxdbr" },
	{ SYSZ_INS_LXEB, "lxeb" },
	{ SYSZ_INS_LXEBR, "lxebr" },
	{ SYSZ_INS_LXR, "lxr" },
	{ SYSZ_INS_LY, "ly" },
	{ SYSZ_INS_LZDR, "lzdr" },
	{ SYSZ_INS_LZER, "lzer" },
	{ SYSZ_INS_LZXR, "lzxr" },
	{ SYSZ_INS_MADB, "madb" },
	{ SYSZ_INS_MADBR, "madbr" },
	{ SYSZ_INS_MAEB, "maeb" },
	{ SYSZ_INS_MAEBR, "maebr" },
	{ SYSZ_INS_MDB, "mdb" },
	{ SYSZ_INS_MDBR, "mdbr" },
	{ SYSZ_INS_MDEB, "mdeb" },
	{ SYSZ_INS_MDEBR, "mdebr" },
	{ SYSZ_INS_MEEB, "meeb" },
	{ SYSZ_INS_MEEBR, "meebr" },
	{ SYSZ_INS_MGHI, "mghi" },
	{ SYSZ_INS_MH, "mh" },
	{ SYSZ_INS_MHI, "mhi" },
	{ SYSZ_INS_MHY, "mhy" },
	{ SYSZ_INS_MLG, "mlg" },
	{ SYSZ_INS_MLGR, "mlgr" },
	{ SYSZ_INS_MS, "ms" },
	{ SYSZ_INS_MSDB, "msdb" },
	{ SYSZ_INS_MSDBR, "msdbr" },
	{ SYSZ_INS_MSEB, "mseb" },
	{ SYSZ_INS_MSEBR, "msebr" },
	{ SYSZ_INS_MSFI, "msfi" },
	{ SYSZ_INS_MSG, "msg" },
	{ SYSZ_INS_MSGF, "msgf" },
	{ SYSZ_INS_MSGFI, "msgfi" },
	{ SYSZ_INS_MSGFR, "msgfr" },
	{ SYSZ_INS_MSGR, "msgr" },
	{ SYSZ_INS_MSR, "msr" },
	{ SYSZ_INS_MSY, "msy" },
	{ SYSZ_INS_MVC, "mvc" },
	{ SYSZ_INS_MVGHI, "mvghi" },
	{ SYSZ_INS_MVHHI, "mvhhi" },
	{ SYSZ_INS_MVHI, "mvhi" },
	{ SYSZ_INS_MVI, "mvi" },
	{ SYSZ_INS_MVIY, "mviy" },
	{ SYSZ_INS_MVST, "mvst" },
	{ SYSZ_INS_MXBR, "mxbr" },
	{ SYSZ_INS_MXDB, "mxdb" },
	{ SYSZ_INS_MXDBR, "mxdbr" },
	{ SYSZ_INS_N, "n" },
	{ SYSZ_INS_NC, "nc" },
	{ SYSZ_INS_NG, "ng" },
	{ SYSZ_INS_NGR, "ngr" },
	{ SYSZ_INS_NGRK, "ngrk" },
	{ SYSZ_INS_NI, "ni" },
	{ SYSZ_INS_NIHF, "nihf" },
	{ SYSZ_INS_NIHH, "nihh" },
	{ SYSZ_INS_NIHL, "nihl" },
	{ SYSZ_INS_NILF, "nilf" },
	{ SYSZ_INS_NILH, "nilh" },
	{ SYSZ_INS_NILL, "nill" },
	{ SYSZ_INS_NIY, "niy" },
	{ SYSZ_INS_NR, "nr" },
	{ SYSZ_INS_NRK, "nrk" },
	{ SYSZ_INS_NY, "ny" },
	{ SYSZ_INS_O, "o" },
	{ SYSZ_INS_OC, "oc" },
	{ SYSZ_INS_OG, "og" },
	{ SYSZ_INS_OGR, "ogr" },
	{ SYSZ_INS_OGRK, "ogrk" },
	{ SYSZ_INS_OI, "oi" },
	{ SYSZ_INS_OIHF, "oihf" },
	{ SYSZ_INS_OIHH, "oihh" },
	{ SYSZ_INS_OIHL, "oihl" },
	{ SYSZ_INS_OILF, "oilf" },
	{ SYSZ_INS_OILH, "oilh" },
	{ SYSZ_INS_OILL, "oill" },
	{ SYSZ_INS_OIY, "oiy" },
	{ SYSZ_INS_OR, "or" },
	{ SYSZ_INS_ORK, "ork" },
	{ SYSZ_INS_OY, "oy" },
	{ SYSZ_INS_PFD, "pfd" },
	{ SYSZ_INS_PFDRL, "pfdrl" },
	{ SYSZ_INS_RISBG, "risbg" },
	{ SYSZ_INS_RISBHG, "risbhg" },
	{ SYSZ_INS_RISBLG, "risblg" },
	{ SYSZ_INS_RLL, "rll" },
	{ SYSZ_INS_RLLG, "rllg" },
	{ SYSZ_INS_RNSBG, "rnsbg" },
	{ SYSZ_INS_ROSBG, "rosbg" },
	{ SYSZ_INS_RXSBG, "rxsbg" },
	{ SYSZ_INS_S, "s" },
	{ SYSZ_INS_SDB, "sdb" },
	{ SYSZ_INS_SDBR, "sdbr" },
	{ SYSZ_INS_SEB, "seb" },
	{ SYSZ_INS_SEBR, "sebr" },
	{ SYSZ_INS_SG, "sg" },
	{ SYSZ_INS_SGF, "sgf" },
	{ SYSZ_INS_SGFR, "sgfr" },
	{ SYSZ_INS_SGR, "sgr" },
	{ SYSZ_INS_SGRK, "sgrk" },
	{ SYSZ_INS_SH, "sh" },
	{ SYSZ_INS_SHY, "shy" },
	{ SYSZ_INS_SL, "sl" },
	{ SYSZ_INS_SLB, "slb" },
	{ SYSZ_INS_SLBG, "slbg" },
	{ SYSZ_INS_SLBR, "slbr" },
	{ SYSZ_INS_SLFI, "slfi" },
	{ SYSZ_INS_SLG, "slg" },
	{ SYSZ_INS_SLBGR, "slbgr" },
	{ SYSZ_INS_SLGF, "slgf" },
	{ SYSZ_INS_SLGFI, "slgfi" },
	{ SYSZ_INS_SLGFR, "slgfr" },
	{ SYSZ_INS_SLGR, "slgr" },
	{ SYSZ_INS_SLGRK, "slgrk" },
	{ SYSZ_INS_SLL, "sll" },
	{ SYSZ_INS_SLLG, "sllg" },
	{ SYSZ_INS_SLLK, "sllk" },
	{ SYSZ_INS_SLR, "slr" },
	{ SYSZ_INS_SLRK, "slrk" },
	{ SYSZ_INS_SLY, "sly" },
	{ SYSZ_INS_SQDB, "sqdb" },
	{ SYSZ_INS_SQDBR, "sqdbr" },
	{ SYSZ_INS_SQEB, "sqeb" },
	{ SYSZ_INS_SQEBR, "sqebr" },
	{ SYSZ_INS_SQXBR, "sqxbr" },
	{ SYSZ_INS_SR, "sr" },
	{ SYSZ_INS_SRA, "sra" },
	{ SYSZ_INS_SRAG, "srag" },
	{ SYSZ_INS_SRAK, "srak" },
	{ SYSZ_INS_SRK, "srk" },
	{ SYSZ_INS_SRL, "srl" },
	{ SYSZ_INS_SRLG, "srlg" },
	{ SYSZ_INS_SRLK, "srlk" },
	{ SYSZ_INS_SRST, "srst" },
	{ SYSZ_INS_ST, "st" },
	{ SYSZ_INS_STC, "stc" },
	{ SYSZ_INS_STCH, "stch" },
	{ SYSZ_INS_STCY, "stcy" },
	{ SYSZ_INS_STD, "std" },
	{ SYSZ_INS_STDY, "stdy" },
	{ SYSZ_INS_STE, "ste" },
	{ SYSZ_INS_STEY, "stey" },
	{ SYSZ_INS_STFH, "stfh" },
	{ SYSZ_INS_STG, "stg" },
	{ SYSZ_INS_STGRL, "stgrl" },
	{ SYSZ_INS_STH, "sth" },
	{ SYSZ_INS_STHH, "sthh" },
	{ SYSZ_INS_STHRL, "sthrl" },
	{ SYSZ_INS_STHY, "sthy" },
	{ SYSZ_INS_STMG, "stmg" },
	{ SYSZ_INS_STRL, "strl" },
	{ SYSZ_INS_STRV, "strv" },
	{ SYSZ_INS_STRVG, "strvg" },
	{ SYSZ_INS_STY, "sty" },
	{ SYSZ_INS_SXBR, "sxbr" },
	{ SYSZ_INS_SY, "sy" },
	{ SYSZ_INS_TM, "tm" },
	{ SYSZ_INS_TMHH, "tmhh" },
	{ SYSZ_INS_TMHL, "tmhl" },
	{ SYSZ_INS_TMLH, "tmlh" },
	{ SYSZ_INS_TMLL, "tmll" },
	{ SYSZ_INS_TMY, "tmy" },
	{ SYSZ_INS_X, "x" },
	{ SYSZ_INS_XC, "xc" },
	{ SYSZ_INS_XG, "xg" },
	{ SYSZ_INS_XGR, "xgr" },
	{ SYSZ_INS_XGRK, "xgrk" },
	{ SYSZ_INS_XI, "xi" },
	{ SYSZ_INS_XIHF, "xihf" },
	{ SYSZ_INS_XILF, "xilf" },
	{ SYSZ_INS_XIY, "xiy" },
	{ SYSZ_INS_XR, "xr" },
	{ SYSZ_INS_XRK, "xrk" },
	{ SYSZ_INS_XY, "xy" },
	{ SYSZ_INS_AD, "ad" },
	{ SYSZ_INS_ADR, "adr" },
	{ SYSZ_INS_ADTR, "adtr" },
	{ SYSZ_INS_ADTRA, "adtra" },
	{ SYSZ_INS_AE, "ae" },
	{ SYSZ_INS_AER, "aer" },
	{ SYSZ_INS_AGH, "agh" },
	{ SYSZ_INS_AHHHR, "ahhhr" },
	{ SYSZ_INS_AHHLR, "ahhlr" },
	{ SYSZ_INS_ALGSI, "algsi" },
	{ SYSZ_INS_ALHHHR, "alhhhr" },
	{ SYSZ_INS_ALHHLR, "alhhlr" },
	{ SYSZ_INS_ALSI, "alsi" },
	{ SYSZ_INS_ALSIH, "alsih" },
	{ SYSZ_INS_ALSIHN, "alsihn" },
	{ SYSZ_INS_AP, "ap" },
	{ SYSZ_INS_AU, "au" },
	{ SYSZ_INS_AUR, "aur" },
	{ SYSZ_INS_AW, "aw" },
	{ SYSZ_INS_AWR, "awr" },
	{ SYSZ_INS_AXR, "axr" },
	{ SYSZ_INS_AXTR, "axtr" },
	{ SYSZ_INS_AXTRA, "axtra" },
	{ SYSZ_INS_B, "b" },
	{ SYSZ_INS_BAKR, "bakr" },
	{ SYSZ_INS_BAL, "bal" },
	{ SYSZ_INS_BALR, "balr" },
	{ SYSZ_INS_BAS, "bas" },
	{ SYSZ_INS_BASSM, "bassm" },
	{ SYSZ_INS_BC, "bc" },
	{ SYSZ_INS_BCT, "bct" },
	{ SYSZ_INS_BCTG, "bctg" },
	{ SYSZ_INS_BCTGR, "bctgr" },
	{ SYSZ_INS_BCTR, "bctr" },
	{ SYSZ_INS_BE, "be" },
	{ SYSZ_INS_BH, "bh" },
	{ SYSZ_INS_BHE, "bhe" },
	{ SYSZ_INS_BI, "bi" },
	{ SYSZ_INS_BIC, "bic" },
	{ SYSZ_INS_BIE, "bie" },
	{ SYSZ_INS_BIH, "bih" },
	{ SYSZ_INS_BIHE, "bihe" },
	{ SYSZ_INS_BIL, "bil" },
	{ SYSZ_INS_BILE, "bile" },
	{ SYSZ_INS_BILH, "bilh" },
	{ SYSZ_INS_BIM, "bim" },
	{ SYSZ_INS_BINE, "bine" },
	{ SYSZ_INS_BINH, "binh" },
	{ SYSZ_INS_BINHE, "binhe" },
	{ SYSZ_INS_BINL, "binl" },
	{ SYSZ_INS_BINLE, "binle" },
	{ SYSZ_INS_BINLH, "binlh" },
	{ SYSZ_INS_BINM, "binm" },
	{ SYSZ_INS_BINO, "bino" },
	{ SYSZ_INS_BINP, "binp" },
	{ SYSZ_INS_BINZ, "binz" },
	{ SYSZ_INS_BIO, "bio" },
	{ SYSZ_INS_BIP, "bip" },
	{ SYSZ_INS_BIZ, "biz" },
	{ SYSZ_INS_BL, "bl" },
	{ SYSZ_INS_BLE, "ble" },
	{ SYSZ_INS_BLH, "blh" },
	{ SYSZ_INS_BM, "bm" },
	{ SYSZ_INS_BMR, "bmr" },
	{ SYSZ_INS_BNE, "bne" },
	{ SYSZ_INS_BNH, "bnh" },
	{ SYSZ_INS_BNHE, "bnhe" },
	{ SYSZ_INS_BNL, "bnl" },
	{ SYSZ_INS_BNLE, "bnle" },
	{ SYSZ_INS_BNLH, "bnlh" },
	{ SYSZ_INS_BNM, "bnm" },
	{ SYSZ_INS_BNMR, "bnmr" },
	{ SYSZ_INS_BNO, "bno" },
	{ SYSZ_INS_BNP, "bnp" },
	{ SYSZ_INS_BNPR, "bnpr" },
	{ SYSZ_INS_BNZ, "bnz" },
	{ SYSZ_INS_BNZR, "bnzr" },
	{ SYSZ_INS_BO, "bo" },
	{ SYSZ_INS_BP, "bp" },
	{ SYSZ_INS_BPP, "bpp" },
	{ SYSZ_INS_BPR, "bpr" },
	{ SYSZ_INS_BPRP, "bprp" },
	{ SYSZ_INS_BRCTH, "brcth" },
	{ SYSZ_INS_BRXH, "brxh" },
	{ SYSZ_INS_BRXHG, "brxhg" },
	{ SYSZ_INS_BRXLE, "brxle" },
	{ SYSZ_INS_BRXLG, "brxlg" },
	{ SYSZ_INS_BSA, "bsa" },
	{ SYSZ_INS_BSG, "bsg" },
	{ SYSZ_INS_BSM, "bsm" },
	{ SYSZ_INS_BXH, "bxh" },
	{ SYSZ_INS_BXHG, "bxhg" },
	{ SYSZ_INS_BXLE, "bxle" },
	{ SYSZ_INS_BXLEG, "bxleg" },
	{ SYSZ_INS_BZ, "bz" },
	{ SYSZ_INS_BZR, "bzr" },
	{ SYSZ_INS_CD, "cd" },
	{ SYSZ_INS_CDFBRA, "cdfbra" },
	{ SYSZ_INS_CDFR, "cdfr" },
	{ SYSZ_INS_CDFTR, "cdftr" },
	{ SYSZ_INS_CDGBRA, "cdgbra" },
	{ SYSZ_INS_CDGR, "cdgr" },
	{ SYSZ_INS_CDGTR, "cdgtr" },
	{ SYSZ_INS_CDGTRA, "cdgtra" },
	{ SYSZ_INS_CDLFTR, "cdlftr" },
	{ SYSZ_INS_CDLGTR, "cdlgtr" },
	{ SYSZ_INS_CDPT, "cdpt" },
	{ SYSZ_INS_CDR, "cdr" },
	{ SYSZ_INS_CDS, "cds" },
	{ SYSZ_INS_CDSG, "cdsg" },
	{ SYSZ_INS_CDSTR, "cdstr" },
	{ SYSZ_INS_CDSY, "cdsy" },
	{ SYSZ_INS_CDTR, "cdtr" },
	{ SYSZ_INS_CDUTR, "cdutr" },
	{ SYSZ_INS_CDZT, "cdzt" },
	{ SYSZ_INS_CE, "ce" },
	{ SYSZ_INS_CEDTR, "cedtr" },
	{ SYSZ_INS_CEFBRA, "cefbra" },
	{ SYSZ_INS_CEFR, "cefr" },
	{ SYSZ_INS_CEGBRA, "cegbra" },
	{ SYSZ_INS_CEGR, "cegr" },
	{ SYSZ_INS_CER, "cer" },
	{ SYSZ_INS_CEXTR, "cextr" },
	{ SYSZ_INS_CFC, "cfc" },
	{ SYSZ_INS_CFDBRA, "cfdbra" },
	{ SYSZ_INS_CFDR, "cfdr" },
	{ SYSZ_INS_CFDTR, "cfdtr" },
	{ SYSZ_INS_CFEBRA, "cfebra" },
	{ SYSZ_INS_CFER, "cfer" },
	{ SYSZ_INS_CFXBRA, "cfxbra" },
	{ SYSZ_INS_CFXR, "cfxr" },
	{ SYSZ_INS_CFXTR, "cfxtr" },
	{ SYSZ_INS_CGDBRA, "cgdbra" },
	{ SYSZ_INS_CGDR, "cgdr" },
	{ SYSZ_INS_CGDTR, "cgdtr" },
	{ SYSZ_INS_CGDTRA, "cgdtra" },
	{ SYSZ_INS_CGEBRA, "cgebra" },
	{ SYSZ_INS_CGER, "cger" },
	{ SYSZ_INS_CGIB, "cgib" },
	{ SYSZ_INS_CGIBE, "cgibe" },
	{ SYSZ_INS_CGIBH, "cgibh" },
	{ SYSZ_INS_CGIBHE, "cgibhe" },
	{ SYSZ_INS_CGIBL, "cgibl" },
	{ SYSZ_INS_CGIBLE, "cgible" },
	{ SYSZ_INS_CGIBLH, "cgiblh" },
	{ SYSZ_INS_CGIBNE, "cgibne" },
	{ SYSZ_INS_CGIBNH, "cgibnh" },
	{ SYSZ_INS_CGIBNHE, "cgibnhe" },
	{ SYSZ_INS_CGIBNL, "cgibnl" },
	{ SYSZ_INS_CGIBNLE, "cgibnle" },
	{ SYSZ_INS_CGIBNLH, "cgibnlh" },
	{ SYSZ_INS_CGIT, "cgit" },
	{ SYSZ_INS_CGITE, "cgite" },
	{ SYSZ_INS_CGITH, "cgith" },
	{ SYSZ_INS_CGITHE, "cgithe" },
	{ SYSZ_INS_CGITL, "cgitl" },
	{ SYSZ_INS_CGITLE, "cgitle" },
	{ SYSZ_INS_CGITLH, "cgitlh" },
	{ SYSZ_INS_CGITNE, "cgitne" },
	{ SYSZ_INS_CGITNH, "cgitnh" },
	{ SYSZ_INS_CGITNHE, "cgitnhe" },
	{ SYSZ_INS_CGITNL, "cgitnl" },
	{ SYSZ_INS_CGITNLE, "cgitnle" },
	{ SYSZ_INS_CGITNLH, "cgitnlh" },
	{ SYSZ_INS_CGRB, "cgrb" },
	{ SYSZ_INS_CGRBE, "cgrbe" },
	{ SYSZ_INS_CGRBH, "cgrbh" },
	{ SYSZ_INS_CGRBHE, "cgrbhe" },
	{ SYSZ_INS_CGRBL, "cgrbl" },
	{ SYSZ_INS_CGRBLE, "cgrble" },
	{ SYSZ_INS_CGRBLH, "cgrblh" },
	{ SYSZ_INS_CGRBNE, "cgrbne" },
	{ SYSZ_INS_CGRBNH, "cgrbnh" },
	{ SYSZ_INS_CGRBNHE, "cgrbnhe" },
	{ SYSZ_INS_CGRBNL, "cgrbnl" },
	{ SYSZ_INS_CGRBNLE, "cgrbnle" },
	{ SYSZ_INS_CGRBNLH, "cgrbnlh" },
	{ SYSZ_INS_CGRT, "cgrt" },
	{ SYSZ_INS_CGRTE, "cgrte" },
	{ SYSZ_INS_CGRTH, "cgrth" },
	{ SYSZ_INS_CGRTHE, "cgrthe" },
	{ SYSZ_INS_CGRTL, "cgrtl" },
	{ SYSZ_INS_CGRTLE, "cgrtle" },
	{ SYSZ_INS_CGRTLH, "cgrtlh" },
	{ SYSZ_INS_CGRTNE, "cgrtne" },
	{ SYSZ_INS_CGRTNH, "cgrtnh" },
	{ SYSZ_INS_CGRTNHE, "cgrtnhe" },
	{ SYSZ_INS_CGRTNL, "cgrtnl" },
	{ SYSZ_INS_CGRTNLE, "cgrtnle" },
	{ SYSZ_INS_CGRTNLH, "cgrtnlh" },
	{ SYSZ_INS_CGXBRA, "cgxbra" },
	{ SYSZ_INS_CGXR, "cgxr" },
	{ SYSZ_INS_CGXTR, "cgxtr" },
	{ SYSZ_INS_CGXTRA, "cgxtra" },
	{ SYSZ_INS_CHHR, "chhr" },
	{ SYSZ_INS_CHLR, "chlr" },
	{ SYSZ_INS_CIB, "cib" },
	{ SYSZ_INS_CIBE, "cibe" },
	{ SYSZ_INS_CIBH, "cibh" },
	{ SYSZ_INS_CIBHE, "cibhe" },
	{ SYSZ_INS_CIBL, "cibl" },
	{ SYSZ_INS_CIBLE, "cible" },
	{ SYSZ_INS_CIBLH, "ciblh" },
	{ SYSZ_INS_CIBNE, "cibne" },
	{ SYSZ_INS_CIBNH, "cibnh" },
	{ SYSZ_INS_CIBNHE, "cibnhe" },
	{ SYSZ_INS_CIBNL, "cibnl" },
	{ SYSZ_INS_CIBNLE, "cibnle" },
	{ SYSZ_INS_CIBNLH, "cibnlh" },
	{ SYSZ_INS_CIT, "cit" },
	{ SYSZ_INS_CITE, "cite" },
	{ SYSZ_INS_CITH, "cith" },
	{ SYSZ_INS_CITHE, "cithe" },
	{ SYSZ_INS_CITL, "citl" },
	{ SYSZ_INS_CITLE, "citle" },
	{ SYSZ_INS_CITLH, "citlh" },
	{ SYSZ_INS_CITNE, "citne" },
	{ SYSZ_INS_CITNH, "citnh" },
	{ SYSZ_INS_CITNHE, "citnhe" },
	{ SYSZ_INS_CITNL, "citnl" },
	{ SYSZ_INS_CITNLE, "citnle" },
	{ SYSZ_INS_CITNLH, "citnlh" },
	{ SYSZ_INS_CKSM, "cksm" },
	{ SYSZ_INS_CLCL, "clcl" },
	{ SYSZ_INS_CLCLE, "clcle" },
	{ SYSZ_INS_CLCLU, "clclu" },
	{ SYSZ_INS_CLFDTR, "clfdtr" },
	{ SYSZ_INS_CLFIT, "clfit" },
	{ SYSZ_INS_CLFITE, "clfite" },
	{ SYSZ_INS_CLFITH, "clfith" },
	{ SYSZ_INS_CLFITHE, "clfithe" },
	{ SYSZ_INS_CLFITL, "clfitl" },
	{ SYSZ_INS_CLFITLE, "clfitle" },
	{ SYSZ_INS_CLFITLH, "clfitlh" },
	{ SYSZ_INS_CLFITNE, "clfitne" },
	{ SYSZ_INS_CLFITNH, "clfitnh" },
	{ SYSZ_INS_CLFITNHE, "clfitnhe" },
	{ SYSZ_INS_CLFITNL, "clfitnl" },
	{ SYSZ_INS_CLFITNLE, "clfitnle" },
	{ SYSZ_INS_CLFITNLH, "clfitnlh" },
	{ SYSZ_INS_CLFXTR, "clfxtr" },
	{ SYSZ_INS_CLGDTR, "clgdtr" },
	{ SYSZ_INS_CLGIB, "clgib" },
	{ SYSZ_INS_CLGIBE, "clgibe" },
	{ SYSZ_INS_CLGIBH, "clgibh" },
	{ SYSZ_INS_CLGIBHE, "clgibhe" },
	{ SYSZ_INS_CLGIBL, "clgibl" },
	{ SYSZ_INS_CLGIBLE, "clgible" },
	{ SYSZ_INS_CLGIBLH, "clgiblh" },
	{ SYSZ_INS_CLGIBNE, "clgibne" },
	{ SYSZ_INS_CLGIBNH, "clgibnh" },
	{ SYSZ_INS_CLGIBNHE, "clgibnhe" },
	{ SYSZ_INS_CLGIBNL, "clgibnl" },
	{ SYSZ_INS_CLGIBNLE, "clgibnle" },
	{ SYSZ_INS_CLGIBNLH, "clgibnlh" },
	{ SYSZ_INS_CLGIT, "clgit" },
	{ SYSZ_INS_CLGITE, "clgite" },
	{ SYSZ_INS_CLGITH, "clgith" },
	{ SYSZ_INS_CLGITHE, "clgithe" },
	{ SYSZ_INS_CLGITL, "clgitl" },
	{ SYSZ_INS_CLGITLE, "clgitle" },
	{ SYSZ_INS_CLGITLH, "clgitlh" },
	{ SYSZ_INS_CLGITNE, "clgitne" },
	{ SYSZ_INS_CLGITNH, "clgitnh" },
	{ SYSZ_INS_CLGITNHE, "clgitnhe" },
	{ SYSZ_INS_CLGITNL, "clgitnl" },
	{ SYSZ_INS_CLGITNLE, "clgitnle" },
	{ SYSZ_INS_CLGITNLH, "clgitnlh" },
	{ SYSZ_INS_CLGRB, "clgrb" },
	{ SYSZ_INS_CLGRBE, "clgrbe" },
	{ SYSZ_INS_CLGRBH, "clgrbh" },
	{ SYSZ_INS_CLGRBHE, "clgrbhe" },
	{ SYSZ_INS_CLGRBL, "clgrbl" },
	{ SYSZ_INS_CLGRBLE, "clgrble" },
	{ SYSZ_INS_CLGRBLH, "clgrblh" },
	{ SYSZ_INS_CLGRBNE, "clgrbne" },
	{ SYSZ_INS_CLGRBNH, "clgrbnh" },
	{ SYSZ_INS_CLGRBNHE, "clgrbnhe" },
	{ SYSZ_INS_CLGRBNL, "clgrbnl" },
	{ SYSZ_INS_CLGRBNLE, "clgrbnle" },
	{ SYSZ_INS_CLGRBNLH, "clgrbnlh" },
	{ SYSZ_INS_CLGRT, "clgrt" },
	{ SYSZ_INS_CLGRTE, "clgrte" },
	{ SYSZ_INS_CLGRTH, "clgrth" },
	{ SYSZ_INS_CLGRTHE, "clgrthe" },
	{ SYSZ_INS_CLGRTL, "clgrtl" },
	{ SYSZ_INS_CLGRTLE, "clgrtle" },
	{ SYSZ_INS_CLGRTLH, "clgrtlh" },
	{ SYSZ_INS_CLGRTNE, "clgrtne" },
	{ SYSZ_INS_CLGRTNH, "clgrtnh" },
	{ SYSZ_INS_CLGRTNHE, "clgrtnhe" },
	{ SYSZ_INS_CLGRTNL, "clgrtnl" },
	{ SYSZ_INS_CLGRTNLE, "clgrtnle" },
	{ SYSZ_INS_CLGRTNLH, "clgrtnlh" },
	{ SYSZ_INS_CLGT, "clgt" },
	{ SYSZ_INS_CLGTE, "clgte" },
	{ SYSZ_INS_CLGTH, "clgth" },
	{ SYSZ_INS_CLGTHE, "clgthe" },
	{ SYSZ_INS_CLGTL, "clgtl" },
	{ SYSZ_INS_CLGTLE, "clgtle" },
	{ SYSZ_INS_CLGTLH, "clgtlh" },
	{ SYSZ_INS_CLGTNE, "clgtne" },
	{ SYSZ_INS_CLGTNH, "clgtnh" },
	{ SYSZ_INS_CLGTNHE, "clgtnhe" },
	{ SYSZ_INS_CLGTNL, "clgtnl" },
	{ SYSZ_INS_CLGTNLE, "clgtnle" },
	{ SYSZ_INS_CLGTNLH, "clgtnlh" },
	{ SYSZ_INS_CLGXTR, "clgxtr" },
	{ SYSZ_INS_CLHHR, "clhhr" },
	{ SYSZ_INS_CLHLR, "clhlr" },
	{ SYSZ_INS_CLIB, "clib" },
	{ SYSZ_INS_CLIBE, "clibe" },
	{ SYSZ_INS_CLIBH, "clibh" },
	{ SYSZ_INS_CLIBHE, "clibhe" },
	{ SYSZ_INS_CLIBL, "clibl" },
	{ SYSZ_INS_CLIBLE, "clible" },
	{ SYSZ_INS_CLIBLH, "cliblh" },
	{ SYSZ_INS_CLIBNE, "clibne" },
	{ SYSZ_INS_CLIBNH, "clibnh" },
	{ SYSZ_INS_CLIBNHE, "clibnhe" },
	{ SYSZ_INS_CLIBNL, "clibnl" },
	{ SYSZ_INS_CLIBNLE, "clibnle" },
	{ SYSZ_INS_CLIBNLH, "clibnlh" },
	{ SYSZ_INS_CLM, "clm" },
	{ SYSZ_INS_CLMH, "clmh" },
	{ SYSZ_INS_CLMY, "clmy" },
	{ SYSZ_INS_CLRB, "clrb" },
	{ SYSZ_INS_CLRBE, "clrbe" },
	{ SYSZ_INS_CLRBH, "clrbh" },
	{ SYSZ_INS_CLRBHE, "clrbhe" },
	{ SYSZ_INS_CLRBL, "clrbl" },
	{ SYSZ_INS_CLRBLE, "clrble" },
	{ SYSZ_INS_CLRBLH, "clrblh" },
	{ SYSZ_INS_CLRBNE, "clrbne" },
	{ SYSZ_INS_CLRBNH, "clrbnh" },
	{ SYSZ_INS_CLRBNHE, "clrbnhe" },
	{ SYSZ_INS_CLRBNL, "clrbnl" },
	{ SYSZ_INS_CLRBNLE, "clrbnle" },
	{ SYSZ_INS_CLRBNLH, "clrbnlh" },
	{ SYSZ_INS_CLRT, "clrt" },
	{ SYSZ_INS_CLRTE, "clrte" },
	{ SYSZ_INS_CLRTH, "clrth" },
	{ SYSZ_INS_CLRTHE, "clrthe" },
	{ SYSZ_INS_CLRTL, "clrtl" },
	{ SYSZ_INS_CLRTLE, "clrtle" },
	{ SYSZ_INS_CLRTLH, "clrtlh" },
	{ SYSZ_INS_CLRTNE, "clrtne" },
	{ SYSZ_INS_CLRTNH, "clrtnh" },
	{ SYSZ_INS_CLRTNHE, "clrtnhe" },
	{ SYSZ_INS_CLRTNL, "clrtnl" },
	{ SYSZ_INS_CLRTNLE, "clrtnle" },
	{ SYSZ_INS_CLRTNLH, "clrtnlh" },
	{ SYSZ_INS_CLT, "clt" },
	{ SYSZ_INS_CLTE, "clte" },
	{ SYSZ_INS_CLTH, "clth" },
	{ SYSZ_INS_CLTHE, "clthe" },
	{ SYSZ_INS_CLTL, "cltl" },
	{ SYSZ_INS_CLTLE, "cltle" },
	{ SYSZ_INS_CLTLH, "cltlh" },
	{ SYSZ_INS_CLTNE, "cltne" },
	{ SYSZ_INS_CLTNH, "cltnh" },
	{ SYSZ_INS_CLTNHE, "cltnhe" },
	{ SYSZ_INS_CLTNL, "cltnl" },
	{ SYSZ_INS_CLTNLE, "cltnle" },
	{ SYSZ_INS_CLTNLH, "cltnlh" },
	{ SYSZ_INS_CMPSC, "cmpsc" },
	{ SYSZ_INS_CP, "cp" },
	{ SYSZ_INS_CPDT, "cpdt" },
	{ SYSZ_INS_CPXT, "cpxt" },
	{ SYSZ_INS_CPYA, "cpya" },
	{ SYSZ_INS_CRB, "crb" },
	{ SYSZ_INS_CRBE, "crbe" },
	{ SYSZ_INS_CRBH, "crbh" },
	{ SYSZ_INS_CRBHE, "crbhe" },
	{ SYSZ_INS_CRBL, "crbl" },
	{ SYSZ_INS_CRBLE, "crble" },
	{ SYSZ_INS_CRBLH, "crblh" },
	{ SYSZ_INS_CRBNE, "crbne" },
	{ SYSZ_INS_CRBNH, "crbnh" },
	{ SYSZ_INS_CRBNHE, "crbnhe" },
	{ SYSZ_INS_CRBNL, "crbnl" },
	{ SYSZ_INS_CRBNLE, "crbnle" },
	{ SYSZ_INS_CRBNLH, "crbnlh" },
	{ SYSZ_INS_CRDTE, "crdte" },
	{ SYSZ_INS_CRT, "crt" },
	{ SYSZ_INS_CRTE, "crte" },
	{ SYSZ_INS_CRTH, "crth" },
	{ SYSZ_INS_CRTHE, "crthe" },
	{ SYSZ_INS_CRTL, "crtl" },
	{ SYSZ_INS_CRTLE, "crtle" },
	{ SYSZ_INS_CRTLH, "crtlh" },
	{ SYSZ_INS_CRTNE, "crtne" },
	{ SYSZ_INS_CRTNH, "crtnh" },
	{ SYSZ_INS_CRTNHE, "crtnhe" },
	{ SYSZ_INS_CRTNL, "crtnl" },
	{ SYSZ_INS_CRTNLE, "crtnle" },
	{ SYSZ_INS_CRTNLH, "crtnlh" },
	{ SYSZ_INS_CSCH, "csch" },
	{ SYSZ_INS_CSDTR, "csdtr" },
	{ SYSZ_INS_CSP, "csp" },
	{ SYSZ_INS_CSPG, "cspg" },
	{ SYSZ_INS_CSST, "csst" },
	{ SYSZ_INS_CSXTR, "csxtr" },
	{ SYSZ_INS_CU12, "cu12" },
	{ SYSZ_INS_CU14, "cu14" },
	{ SYSZ_INS_CU21, "cu21" },
	{ SYSZ_INS_CU24, "cu24" },
	{ SYSZ_INS_CU41, "cu41" },
	{ SYSZ_INS_CU42, "cu42" },
	{ SYSZ_INS_CUDTR, "cudtr" },
	{ SYSZ_INS_CUSE, "cuse" },
	{ SYSZ_INS_CUTFU, "cutfu" },
	{ SYSZ_INS_CUUTF, "cuutf" },
	{ SYSZ_INS_CUXTR, "cuxtr" },
	{ SYSZ_INS_CVB, "cvb" },
	{ SYSZ_INS_CVBG, "cvbg" },
	{ SYSZ_INS_CVBY, "cvby" },
	{ SYSZ_INS_CVD, "cvd" },
	{ SYSZ_INS_CVDG, "cvdg" },
	{ SYSZ_INS_CVDY, "cvdy" },
	{ SYSZ_INS_CXFBRA, "cxfbra" },
	{ SYSZ_INS_CXFR, "cxfr" },
	{ SYSZ_INS_CXFTR, "cxftr" },
	{ SYSZ_INS_CXGBRA, "cxgbra" },
	{ SYSZ_INS_CXGR, "cxgr" },
	{ SYSZ_INS_CXGTR, "cxgtr" },
	{ SYSZ_INS_CXGTRA, "cxgtra" },
	{ SYSZ_INS_CXLFTR, "cxlftr" },
	{ SYSZ_INS_CXLGTR, "cxlgtr" },
	{ SYSZ_INS_CXPT, "cxpt" },
	{ SYSZ_INS_CXR, "cxr" },
	{ SYSZ_INS_CXSTR, "cxstr" },
	{ SYSZ_INS_CXTR, "cxtr" },
	{ SYSZ_INS_CXUTR, "cxutr" },
	{ SYSZ_INS_CXZT, "cxzt" },
	{ SYSZ_INS_CZDT, "czdt" },
	{ SYSZ_INS_CZXT, "czxt" },
	{ SYSZ_INS_D, "d" },
	{ SYSZ_INS_DD, "dd" },
	{ SYSZ_INS_DDR, "ddr" },
	{ SYSZ_INS_DDTR, "ddtr" },
	{ SYSZ_INS_DDTRA, "ddtra" },
	{ SYSZ_INS_DE, "de" },
	{ SYSZ_INS_DER, "der" },
	{ SYSZ_INS_DIAG, "diag" },
	{ SYSZ_INS_DIDBR, "didbr" },
	{ SYSZ_INS_DIEBR, "diebr" },
	{ SYSZ_INS_DP, "dp" },
	{ SYSZ_INS_DR, "dr" },
	{ SYSZ_INS_DXR, "dxr" },
	{ SYSZ_INS_DXTR, "dxtr" },
	{ SYSZ_INS_DXTRA, "dxtra" },
	{ SYSZ_INS_ECAG, "ecag" },
	{ SYSZ_INS_ECCTR, "ecctr" },
	{ SYSZ_INS_ECPGA, "ecpga" },
	{ SYSZ_INS_ECTG, "ectg" },
	{ SYSZ_INS_ED, "ed" },
	{ SYSZ_INS_EDMK, "edmk" },
	{ SYSZ_INS_EEDTR, "eedtr" },
	{ SYSZ_INS_EEXTR, "eextr" },
	{ SYSZ_INS_EFPC, "efpc" },
	{ SYSZ_INS_EPAIR, "epair" },
	{ SYSZ_INS_EPAR, "epar" },
	{ SYSZ_INS_EPCTR, "epctr" },
	{ SYSZ_INS_EPSW, "epsw" },
	{ SYSZ_INS_EREG, "ereg" },
	{ SYSZ_INS_EREGG, "eregg" },
	{ SYSZ_INS_ESAIR, "esair" },
	{ SYSZ_INS_ESAR, "esar" },
	{ SYSZ_INS_ESDTR, "esdtr" },
	{ SYSZ_INS_ESEA, "esea" },
	{ SYSZ_INS_ESTA, "esta" },
	{ SYSZ_INS_ESXTR, "esxtr" },
	{ SYSZ_INS_ETND, "etnd" },
	{ SYSZ_INS_EX, "ex" },
	{ SYSZ_INS_EXRL, "exrl" },
	{ SYSZ_INS_FIDR, "fidr" },
	{ SYSZ_INS_FIDTR, "fidtr" },
	{ SYSZ_INS_FIER, "fier" },
	{ SYSZ_INS_FIXR, "fixr" },
	{ SYSZ_INS_FIXTR, "fixtr" },
	{ SYSZ_INS_HDR, "hdr" },
	{ SYSZ_INS_HER, "her" },
	{ SYSZ_INS_HSCH, "hsch" },
	{ SYSZ_INS_IAC, "iac" },
	{ SYSZ_INS_ICM, "icm" },
	{ SYSZ_INS_ICMH, "icmh" },
	{ SYSZ_INS_ICMY, "icmy" },
	{ SYSZ_INS_IDTE, "idte" },
	{ SYSZ_INS_IEDTR, "iedtr" },
	{ SYSZ_INS_IEXTR, "iextr" },
	{ SYSZ_INS_IPK, "ipk" },
	{ SYSZ_INS_IPTE, "ipte" },
	{ SYSZ_INS_IRBM, "irbm" },
	{ SYSZ_INS_ISKE, "iske" },
	{ SYSZ_INS_IVSK, "ivsk" },
	{ SYSZ_INS_JGM, "jgm" },
	{ SYSZ_INS_JGNM, "jgnm" },
	{ SYSZ_INS_JGNP, "jgnp" },
	{ SYSZ_INS_JGNZ, "jgnz" },
	{ SYSZ_INS_JGP, "jgp" },
	{ SYSZ_INS_JGZ, "jgz" },
	{ SYSZ_INS_JM, "jm" },
	{ SYSZ_INS_JNM, "jnm" },
	{ SYSZ_INS_JNP, "jnp" },
	{ SYSZ_INS_JNZ, "jnz" },
	{ SYSZ_INS_JP, "jp" },
	{ SYSZ_INS_JZ, "jz" },
	{ SYSZ_INS_KDB, "kdb" },
	{ SYSZ_INS_KDBR, "kdbr" },
	{ SYSZ_INS_KDTR, "kdtr" },
	{ SYSZ_INS_KEB, "keb" },
	{ SYSZ_INS_KEBR, "kebr" },
	{ SYSZ_INS_KIMD, "kimd" },
	{ SYSZ_INS_KLMD, "klmd" },
	{ SYSZ_INS_KM, "km" },
	{ SYSZ_INS_KMA, "kma" },
	{ SYSZ_INS_KMAC, "kmac" },
	{ SYSZ_INS_KMC, "kmc" },
	{ SYSZ_INS_KMCTR, "kmctr" },
	{ SYSZ_INS_KMF, "kmf" },
	{ SYSZ_INS_KMO, "kmo" },
	{ SYSZ_INS_KXBR, "kxbr" },
	{ SYSZ_INS_KXTR, "kxtr" },
	{ SYSZ_INS_LAE, "lae" },
	{ SYSZ_INS_LAEY, "laey" },
	{ SYSZ_INS_LAM, "lam" },
	{ SYSZ_INS_LAMY, "lamy" },
	{ SYSZ_INS_LASP, "lasp" },
	{ SYSZ_INS_LAT, "lat" },
	{ SYSZ_INS_LCBB, "lcbb" },
	{ SYSZ_INS_LCCTL, "lcctl" },
	{ SYSZ_INS_LCDFR, "lcdfr" },
	{ SYSZ_INS_LCDR, "lcdr" },
	{ SYSZ_INS_LCER, "lcer" },
	{ SYSZ_INS_LCTL, "lctl" },
	{ SYSZ_INS_LCTLG, "lctlg" },
	{ SYSZ_INS_LCXR, "lcxr" },
	{ SYSZ_INS_LDE, "lde" },
	{ SYSZ_INS_LDER, "lder" },
	{ SYSZ_INS_LDETR, "ldetr" },
	{ SYSZ_INS_LDXR, "ldxr" },
	{ SYSZ_INS_LDXTR, "ldxtr" },
	{ SYSZ_INS_LEDR, "ledr" },
	{ SYSZ_INS_LEDTR, "ledtr" },
	{ SYSZ_INS_LEXR, "lexr" },
	{ SYSZ_INS_LFAS, "lfas" },
	{ SYSZ_INS_LFHAT, "lfhat" },
	{ SYSZ_INS_LFPC, "lfpc" },
	{ SYSZ_INS_LGAT, "lgat" },
	{ SYSZ_INS_LGG, "lgg" },
	{ SYSZ_INS_LGSC, "lgsc" },
	{ SYSZ_INS_LLGFAT, "llgfat" },
	{ SYSZ_INS_LLGFSG, "llgfsg" },
	{ SYSZ_INS_LLGT, "llgt" },
	{ SYSZ_INS_LLGTAT, "llgtat" },
	{ SYSZ_INS_LLGTR, "llgtr" },
	{ SYSZ_INS_LLZRGF, "llzrgf" },
	{ SYSZ_INS_LM, "lm" },
	{ SYSZ_INS_LMD, "lmd" },
	{ SYSZ_INS_LMH, "lmh" },
	{ SYSZ_INS_LMY, "lmy" },
	{ SYSZ_INS_LNDFR, "lndfr" },
	{ SYSZ_INS_LNDR, "lndr" },
	{ SYSZ_INS_LNER, "lner" },
	{ SYSZ_INS_LNXR, "lnxr" },
	{ SYSZ_INS_LOCFH, "locfh" },
	{ SYSZ_INS_LOCFHE, "locfhe" },
	{ SYSZ_INS_LOCFHH, "locfhh" },
	{ SYSZ_INS_LOCFHHE, "locfhhe" },
	{ SYSZ_INS_LOCFHL, "locfhl" },
	{ SYSZ_INS_LOCFHLE, "locfhle" },
	{ SYSZ_INS_LOCFHLH, "locfhlh" },
	{ SYSZ_INS_LOCFHM, "locfhm" },
	{ SYSZ_INS_LOCFHNE, "locfhne" },
	{ SYSZ_INS_LOCFHNH, "locfhnh" },
	{ SYSZ_INS_LOCFHNHE, "locfhnhe" },
	{ SYSZ_INS_LOCFHNL, "locfhnl" },
	{ SYSZ_INS_LOCFHNLE, "locfhnle" },
	{ SYSZ_INS_LOCFHNLH, "locfhnlh" },
	{ SYSZ_INS_LOCFHNM, "locfhnm" },
	{ SYSZ_INS_LOCFHNO, "locfhno" },
	{ SYSZ_INS_LOCFHNP, "locfhnp" },
	{ SYSZ_INS_LOCFHNZ, "locfhnz" },
	{ SYSZ_INS_LOCFHO, "locfho" },
	{ SYSZ_INS_LOCFHP, "locfhp" },
	{ SYSZ_INS_LOCFHR, "locfhr" },
	{ SYSZ_INS_LOCFHRE, "locfhre" },
	{ SYSZ_INS_LOCFHRH, "locfhrh" },
	{ SYSZ_INS_LOCFHRHE, "locfhrhe" },
	{ SYSZ_INS_LOCFHRL, "locfhrl" },
	{ SYSZ_INS_LOCFHRLE, "locfhrle" },
	{ SYSZ_INS_LOCFHRLH, "locfhrlh" },
	{ SYSZ_INS_LOCFHRM, "locfhrm" },
	{ SYSZ_INS_LOCFHRNE, "locfhrne" },
	{ SYSZ_INS_LOCFHRNH, "locfhrnh" },
	{ SYSZ_INS_LOCFHRNHE, "locfhrnhe" },
	{ SYSZ_INS_LOCFHRNL, "locfhrnl" },
	{ SYSZ_INS_LOCFHRNLE, "locfhrnle" },
	{ SYSZ_INS_LOCFHRNLH, "locfhrnlh" },
	{ SYSZ_INS_LOCFHRNM, "locfhrnm" },
	{ SYSZ_INS_LOCFHRNO, "locfhrno" },
	{ SYSZ_INS_LOCFHRNP, "locfhrnp" },
	{ SYSZ_INS_LOCFHRNZ, "locfhrnz" },
	{ SYSZ_INS_LOCFHRO, "locfhro" },
	{ SYSZ_INS_LOCFHRP, "locfhrp" },
	{ SYSZ_INS_LOCFHRZ, "locfhrz" },
	{ SYSZ_INS_LOCFHZ, "locfhz" },
	{ SYSZ_INS_LOCGHI, "locghi" },
	{ SYSZ_INS_LOCGHIE, "locghie" },
	{ SYSZ_INS_LOCGHIH, "locghih" },
	{ SYSZ_INS_LOCGHIHE, "locghihe" },
	{ SYSZ_INS_LOCGHIL, "locghil" },
	{ SYSZ_INS_LOCGHILE, "locghile" },
	{ SYSZ_INS_LOCGHILH, "locghilh" },
	{ SYSZ_INS_LOCGHIM, "locghim" },
	{ SYSZ_INS_LOCGHINE, "locghine" },
	{ SYSZ_INS_LOCGHINH, "locghinh" },
	{ SYSZ_INS_LOCGHINHE, "locghinhe" },
	{ SYSZ_INS_LOCGHINL, "locghinl" },
	{ SYSZ_INS_LOCGHINLE, "locghinle" },
	{ SYSZ_INS_LOCGHINLH, "locghinlh" },
	{ SYSZ_INS_LOCGHINM, "locghinm" },
	{ SYSZ_INS_LOCGHINO, "locghino" },
	{ SYSZ_INS_LOCGHINP, "locghinp" },
	{ SYSZ_INS_LOCGHINZ, "locghinz" },
	{ SYSZ_INS_LOCGHIO, "locghio" },
	{ SYSZ_INS_LOCGHIP, "locghip" },
	{ SYSZ_INS_LOCGHIZ, "locghiz" },
	{ SYSZ_INS_LOCGM, "locgm" },
	{ SYSZ_INS_LOCGNM, "locgnm" },
	{ SYSZ_INS_LOCGNP, "locgnp" },
	{ SYSZ_INS_LOCGNZ, "locgnz" },
	{ SYSZ_INS_LOCGP, "locgp" },
	{ SYSZ_INS_LOCGRM, "locgrm" },
	{ SYSZ_INS_LOCGRNM, "locgrnm" },
	{ SYSZ_INS_LOCGRNP, "locgrnp" },
	{ SYSZ_INS_LOCGRNZ, "locgrnz" },
	{ SYSZ_INS_LOCGRP, "locgrp" },
	{ SYSZ_INS_LOCGRZ, "locgrz" },
	{ SYSZ_INS_LOCGZ, "locgz" },
	{ SYSZ_INS_LOCHHI, "lochhi" },
	{ SYSZ_INS_LOCHHIE, "lochhie" },
	{ SYSZ_INS_LOCHHIH, "lochhih" },
	{ SYSZ_INS_LOCHHIHE, "lochhihe" },
	{ SYSZ_INS_LOCHHIL, "lochhil" },
	{ SYSZ_INS_LOCHHILE, "lochhile" },
	{ SYSZ_INS_LOCHHILH, "lochhilh" },
	{ SYSZ_INS_LOCHHIM, "lochhim" },
	{ SYSZ_INS_LOCHHINE, "lochhine" },
	{ SYSZ_INS_LOCHHINH, "lochhinh" },
	{ SYSZ_INS_LOCHHINHE, "lochhinhe" },
	{ SYSZ_INS_LOCHHINL, "lochhinl" },
	{ SYSZ_INS_LOCHHINLE, "lochhinle" },
	{ SYSZ_INS_LOCHHINLH, "lochhinlh" },
	{ SYSZ_INS_LOCHHINM, "lochhinm" },
	{ SYSZ_INS_LOCHHINO, "lochhino" },
	{ SYSZ_INS_LOCHHINP, "lochhinp" },
	{ SYSZ_INS_LOCHHINZ, "lochhinz" },
	{ SYSZ_INS_LOCHHIO, "lochhio" },
	{ SYSZ_INS_LOCHHIP, "lochhip" },
	{ SYSZ_INS_LOCHHIZ, "lochhiz" },
	{ SYSZ_INS_LOCHI, "lochi" },
	{ SYSZ_INS_LOCHIE, "lochie" },
	{ SYSZ_INS_LOCHIH, "lochih" },
	{ SYSZ_INS_LOCHIHE, "lochihe" },
	{ SYSZ_INS_LOCHIL, "lochil" },
	{ SYSZ_INS_LOCHILE, "lochile" },
	{ SYSZ_INS_LOCHILH, "lochilh" },
	{ SYSZ_INS_LOCHIM, "lochim" },
	{ SYSZ_INS_LOCHINE, "lochine" },
	{ SYSZ_INS_LOCHINH, "lochinh" },
	{ SYSZ_INS_LOCHINHE, "lochinhe" },
	{ SYSZ_INS_LOCHINL, "lochinl" },
	{ SYSZ_INS_LOCHINLE, "lochinle" },
	{ SYSZ_INS_LOCHINLH, "lochinlh" },
	{ SYSZ_INS_LOCHINM, "lochinm" },
	{ SYSZ_INS_LOCHINO, "lochino" },
	{ SYSZ_INS_LOCHINP, "lochinp" },
	{ SYSZ_INS_LOCHINZ, "lochinz" },
	{ SYSZ_INS_LOCHIO, "lochio" },
	{ SYSZ_INS_LOCHIP, "lochip" },
	{ SYSZ_INS_LOCHIZ, "lochiz" },
	{ SYSZ_INS_LOCM, "locm" },
	{ SYSZ_INS_LOCNM, "locnm" },
	{ SYSZ_INS_LOCNP, "locnp" },
	{ SYSZ_INS_LOCNZ, "locnz" },
	{ SYSZ_INS_LOCP, "locp" },
	{ SYSZ_INS_LOCRM, "locrm" },
	{ SYSZ_INS_LOCRNM, "locrnm" },
	{ SYSZ_INS_LOCRNP, "locrnp" },
	{ SYSZ_INS_LOCRNZ, "locrnz" },
	{ SYSZ_INS_LOCRP, "locrp" },
	{ SYSZ_INS_LOCRZ, "locrz" },
	{ SYSZ_INS_LOCZ, "locz" },
	{ SYSZ_INS_LPCTL, "lpctl" },
	{ SYSZ_INS_LPD, "lpd" },
	{ SYSZ_INS_LPDFR, "lpdfr" },
	{ SYSZ_INS_LPDG, "lpdg" },
	{ SYSZ_INS_LPDR, "lpdr" },
	{ SYSZ_INS_LPER, "lper" },
	{ SYSZ_INS_LPP, "lpp" },
	{ SYSZ_INS_LPQ, "lpq" },
	{ SYSZ_INS_LPSW, "lpsw" },
	{ SYSZ_INS_LPSWE, "lpswe" },
	{ SYSZ_INS_LPTEA, "lptea" },
	{ SYSZ_INS_LPXR, "lpxr" },
	{ SYSZ_INS_LRA, "lra" },
	{ SYSZ_INS_LRAG, "lrag" },
	{ SYSZ_INS_LRAY, "lray" },
	{ SYSZ_INS_LRDR, "lrdr" },
	{ SYSZ_INS_LRER, "lrer" },
	{ SYSZ_INS_LRVH, "lrvh" },
	{ SYSZ_INS_LSCTL, "lsctl" },
	{ SYSZ_INS_LTDR, "ltdr" },
	{ SYSZ_INS_LTDTR, "ltdtr" },
	{ SYSZ_INS_LTER, "lter" },
	{ SYSZ_INS_LTXR, "ltxr" },
	{ SYSZ_INS_LTXTR, "ltxtr" },
	{ SYSZ_INS_LURA, "lura" },
	{ SYSZ_INS_LURAG, "lurag" },
	{ SYSZ_INS_LXD, "lxd" },
	{ SYSZ_INS_LXDR, "lxdr" },
	{ SYSZ_INS_LXDTR, "lxdtr" },
	{ SYSZ_INS_LXE, "lxe" },
	{ SYSZ_INS_LXER, "lxer" },
	{ SYSZ_INS_LZRF, "lzrf" },
	{ SYSZ_INS_LZRG, "lzrg" },
	{ SYSZ_INS_M, "m" },
	{ SYSZ_INS_MAD, "mad" },
	{ SYSZ_INS_MADR, "madr" },
	{ SYSZ_INS_MAE, "mae" },
	{ SYSZ_INS_MAER, "maer" },
	{ SYSZ_INS_MAY, "may" },
	{ SYSZ_INS_MAYH, "mayh" },
	{ SYSZ_INS_MAYHR, "mayhr" },
	{ SYSZ_INS_MAYL, "mayl" },
	{ SYSZ_INS_MAYLR, "maylr" },
	{ SYSZ_INS_MAYR, "mayr" },
	{ SYSZ_INS_MC, "mc" },
	{ SYSZ_INS_MD, "md" },
	{ SYSZ_INS_MDE, "mde" },
	{ SYSZ_INS_MDER, "mder" },
	{ SYSZ_INS_MDR, "mdr" },
	{ SYSZ_INS_MDTR, "mdtr" },
	{ SYSZ_INS_MDTRA, "mdtra" },
	{ SYSZ_INS_ME, "me" },
	{ SYSZ_INS_MEE, "mee" },
	{ SYSZ_INS_MEER, "meer" },
	{ SYSZ_INS_MER, "mer" },
	{ SYSZ_INS_MFY, "mfy" },
	{ SYSZ_INS_MG, "mg" },
	{ SYSZ_INS_MGH, "mgh" },
	{ SYSZ_INS_MGRK, "mgrk" },
	{ SYSZ_INS_ML, "ml" },
	{ SYSZ_INS_MLR, "mlr" },
	{ SYSZ_INS_MP, "mp" },
	{ SYSZ_INS_MR, "mr" },
	{ SYSZ_INS_MSC, "msc" },
	{ SYSZ_INS_MSCH, "msch" },
	{ SYSZ_INS_MSD, "msd" },
	{ SYSZ_INS_MSDR, "msdr" },
	{ SYSZ_INS_MSE, "mse" },
	{ SYSZ_INS_MSER, "mser" },
	{ SYSZ_INS_MSGC, "msgc" },
	{ SYSZ_INS_MSGRKC, "msgrkc" },
	{ SYSZ_INS_MSRKC, "msrkc" },
	{ SYSZ_INS_MSTA, "msta" },
	{ SYSZ_INS_MVCDK, "mvcdk" },
	{ SYSZ_INS_MVCIN, "mvcin" },
	{ SYSZ_INS_MVCK, "mvck" },
	{ SYSZ_INS_MVCL, "mvcl" },
	{ SYSZ_INS_MVCLE, "mvcle" },
	{ SYSZ_INS_MVCLU, "mvclu" },
	{ SYSZ_INS_MVCOS, "mvcos" },
	{ SYSZ_INS_MVCP, "mvcp" },
	{ SYSZ_INS_MVCS, "mvcs" },
	{ SYSZ_INS_MVCSK, "mvcsk" },
	{ SYSZ_INS_MVN, "mvn" },
	{ SYSZ_INS_MVO, "mvo" },
	{ SYSZ_INS_MVPG, "mvpg" },
	{ SYSZ_INS_MVZ, "mvz" },
	{ SYSZ_INS_MXD, "mxd" },
	{ SYSZ_INS_MXDR, "mxdr" },
	{ SYSZ_INS_MXR, "mxr" },
	{ SYSZ_INS_MXTR, "mxtr" },
	{ SYSZ_INS_MXTRA, "mxtra" },
	{ SYSZ_INS_MY, "my" },
	{ SYSZ_INS_MYH, "myh" },
	{ SYSZ_INS_MYHR, "myhr" },
	{ SYSZ_INS_MYL, "myl" },
	{ SYSZ_INS_MYLR, "mylr" },
	{ SYSZ_INS_MYR, "myr" },
	{ SYSZ_INS_NIAI, "niai" },
	{ SYSZ_INS_NTSTG, "ntstg" },
	{ SYSZ_INS_PACK, "pack" },
	{ SYSZ_INS_PALB, "palb" },
	{ SYSZ_INS_PC, "pc" },
	{ SYSZ_INS_PCC, "pcc" },
	{ SYSZ_INS_PCKMO, "pckmo" },
	{ SYSZ_INS_PFMF, "pfmf" },
	{ SYSZ_INS_PFPO, "pfpo" },
	{ SYSZ_INS_PGIN, "pgin" },
	{ SYSZ_INS_PGOUT, "pgout" },
	{ SYSZ_INS_PKA, "pka" },
	{ SYSZ_INS_PKU, "pku" },
	{ SYSZ_INS_PLO, "plo" },
	{ SYSZ_INS_POPCNT, "popcnt" },
	{ SYSZ_INS_PPA, "ppa" },
	{ SYSZ_INS_PPNO, "ppno" },
	{ SYSZ_INS_PR, "pr" },
	{ SYSZ_INS_PRNO, "prno" },
	{ SYSZ_INS_PT, "pt" },
	{ SYSZ_INS_PTF, "ptf" },
	{ SYSZ_INS_PTFF, "ptff" },
	{ SYSZ_INS_PTI, "pti" },
	{ SYSZ_INS_PTLB, "ptlb" },
	{ SYSZ_INS_QADTR, "qadtr" },
	{ SYSZ_INS_QAXTR, "qaxtr" },
	{ SYSZ_INS_QCTRI, "qctri" },
	{ SYSZ_INS_QSI, "qsi" },
	{ SYSZ_INS_RCHP, "rchp" },
	{ SYSZ_INS_RISBGN, "risbgn" },
	{ SYSZ_INS_RP, "rp" },
	{ SYSZ_INS_RRBE, "rrbe" },
	{ SYSZ_INS_RRBM, "rrbm" },
	{ SYSZ_INS_RRDTR, "rrdtr" },
	{ SYSZ_INS_RRXTR, "rrxtr" },
	{ SYSZ_INS_RSCH, "rsch" },
	{ SYSZ_INS_SAC, "sac" },
	{ SYSZ_INS_SACF, "sacf" },
	{ SYSZ_INS_SAL, "sal" },
	{ SYSZ_INS_SAM24, "sam24" },
	{ SYSZ_INS_SAM31, "sam31" },
	{ SYSZ_INS_SAM64, "sam64" },
	{ SYSZ_INS_SAR, "sar" },
	{ SYSZ_INS_SCCTR, "scctr" },
	{ SYSZ_INS_SCHM, "schm" },
	{ SYSZ_INS_SCK, "sck" },
	{ SYSZ_INS_SCKC, "sckc" },
	{ SYSZ_INS_SCKPF, "sckpf" },
	{ SYSZ_INS_SD, "sd" },
	{ SYSZ_INS_SDR, "sdr" },
	{ SYSZ_INS_SDTR, "sdtr" },
	{ SYSZ_INS_SDTRA, "sdtra" },
	{ SYSZ_INS_SE, "se" },
	{ SYSZ_INS_SER, "ser" },
	{ SYSZ_INS_SFASR, "sfasr" },
	{ SYSZ_INS_SFPC, "sfpc" },
	{ SYSZ_INS_SGH, "sgh" },
	{ SYSZ_INS_SHHHR, "shhhr" },
	{ SYSZ_INS_SHHLR, "shhlr" },
	{ SYSZ_INS_SIE, "sie" },
	{ SYSZ_INS_SIGA, "siga" },
	{ SYSZ_INS_SIGP, "sigp" },
	{ SYSZ_INS_SLA, "sla" },
	{ SYSZ_INS_SLAG, "slag" },
	{ SYSZ_INS_SLAK, "slak" },
	{ SYSZ_INS_SLDA, "slda" },
	{ SYSZ_INS_SLDL, "sldl" },
	{ SYSZ_INS_SLDT, "sldt" },
	{ SYSZ_INS_SLHHHR, "slhhhr" },
	{ SYSZ_INS_SLHHLR, "slhhlr" },
	{ SYSZ_INS_SLXT, "slxt" },
	{ SYSZ_INS_SP, "sp" },
	{ SYSZ_INS_SPCTR, "spctr" },
	{ SYSZ_INS_SPKA, "spka" },
	{ SYSZ_INS_SPM, "spm" },
	{ SYSZ_INS_SPT, "spt" },
	{ SYSZ_INS_SPX, "spx" },
	{ SYSZ_INS_SQD, "sqd" },
	{ SYSZ_INS_SQDR, "sqdr" },
	{ SYSZ_INS_SQE, "sqe" },
	{ SYSZ_INS_SQER, "sqer" },
	{ SYSZ_INS_SQXR, "sqxr" },
	{ SYSZ_INS_SRDA, "srda" },
	{ SYSZ_INS_SRDL, "srdl" },
	{ SYSZ_INS_SRDT, "srdt" },
	{ SYSZ_INS_SRNM, "srnm" },
	{ SYSZ_INS_SRNMB, "srnmb" },
	{ SYSZ_INS_SRNMT, "srnmt" },
	{ SYSZ_INS_SRP, "srp" },
	{ SYSZ_INS_SRSTU, "srstu" },
	{ SYSZ_INS_SRXT, "srxt" },
	{ SYSZ_INS_SSAIR, "ssair" },
	{ SYSZ_INS_SSAR, "ssar" },
	{ SYSZ_INS_SSCH, "ssch" },
	{ SYSZ_INS_SSKE, "sske" },
	{ SYSZ_INS_SSM, "ssm" },
	{ SYSZ_INS_STAM, "stam" },
	{ SYSZ_INS_STAMY, "stamy" },
	{ SYSZ_INS_STAP, "stap" },
	{ SYSZ_INS_STCK, "stck" },
	{ SYSZ_INS_STCKC, "stckc" },
	{ SYSZ_INS_STCKE, "stcke" },
	{ SYSZ_INS_STCKF, "stckf" },
	{ SYSZ_INS_STCM, "stcm" },
	{ SYSZ_INS_STCMH, "stcmh" },
	{ SYSZ_INS_STCMY, "stcmy" },
	{ SYSZ_INS_STCPS, "stcps" },
	{ SYSZ_INS_STCRW, "stcrw" },
	{ SYSZ_INS_STCTG, "stctg" },
	{ SYSZ_INS_STCTL, "stctl" },
	{ SYSZ_INS_STFL, "stfl" },
	{ SYSZ_INS_STFLE, "stfle" },
	{ SYSZ_INS_STFPC, "stfpc" },
	{ SYSZ_INS_STGSC, "stgsc" },
	{ SYSZ_INS_STIDP, "stidp" },
	{ SYSZ_INS_STM, "stm" },
	{ SYSZ_INS_STMH, "stmh" },
	{ SYSZ_INS_STMY, "stmy" },
	{ SYSZ_INS_STNSM, "stnsm" },
	{ SYSZ_INS_STOCFH, "stocfh" },
	{ SYSZ_INS_STOCFHE, "stocfhe" },
	{ SYSZ_INS_STOCFHH, "stocfhh" },
	{ SYSZ_INS_STOCFHHE, "stocfhhe" },
	{ SYSZ_INS_STOCFHL, "stocfhl" },
	{ SYSZ_INS_STOCFHLE, "stocfhle" },
	{ SYSZ_INS_STOCFHLH, "stocfhlh" },
	{ SYSZ_INS_STOCFHM, "stocfhm" },
	{ SYSZ_INS_STOCFHNE, "stocfhne" },
	{ SYSZ_INS_STOCFHNH, "stocfhnh" },
	{ SYSZ_INS_STOCFHNHE, "stocfhnhe" },
	{ SYSZ_INS_STOCFHNL, "stocfhnl" },
	{ SYSZ_INS_STOCFHNLE, "stocfhnle" },
	{ SYSZ_INS_STOCFHNLH, "stocfhnlh" },
	{ SYSZ_INS_STOCFHNM, "stocfhnm" },
	{ SYSZ_INS_STOCFHNO, "stocfhno" },
	{ SYSZ_INS_STOCFHNP, "stocfhnp" },
	{ SYSZ_INS_STOCFHNZ, "stocfhnz" },
	{ SYSZ_INS_STOCFHO, "stocfho" },
	{ SYSZ_INS_STOCFHP, "stocfhp" },
	{ SYSZ_INS_STOCFHZ, "stocfhz" },
	{ SYSZ_INS_STOCGM, "stocgm" },
	{ SYSZ_INS_STOCGNM, "stocgnm" },
	{ SYSZ_INS_STOCGNP, "stocgnp" },
	{ SYSZ_INS_STOCGNZ, "stocgnz" },
	{ SYSZ_INS_STOCGP, "stocgp" },
	{ SYSZ_INS_STOCGZ, "stocgz" },
	{ SYSZ_INS_STOCM, "stocm" },
	{ SYSZ_INS_STOCNM, "stocnm" },
	{ SYSZ_INS_STOCNP, "stocnp" },
	{ SYSZ_INS_STOCNZ, "stocnz" },
	{ SYSZ_INS_STOCP, "stocp" },
	{ SYSZ_INS_STOCZ, "stocz" },
	{ SYSZ_INS_STOSM, "stosm" },
	{ SYSZ_INS_STPQ, "stpq" },
	{ SYSZ_INS_STPT, "stpt" },
	{ SYSZ_INS_STPX, "stpx" },
	{ SYSZ_INS_STRAG, "strag" },
	{ SYSZ_INS_STRVH, "strvh" },
	{ SYSZ_INS_STSCH, "stsch" },
	{ SYSZ_INS_STSI, "stsi" },
	{ SYSZ_INS_STURA, "stura" },
	{ SYSZ_INS_STURG, "sturg" },
	{ SYSZ_INS_SU, "su" },
	{ SYSZ_INS_SUR, "sur" },
	{ SYSZ_INS_SVC, "svc" },
	{ SYSZ_INS_SW, "sw" },
	{ SYSZ_INS_SWR, "swr" },
	{ SYSZ_INS_SXR, "sxr" },
	{ SYSZ_INS_SXTR, "sxtr" },
	{ SYSZ_INS_SXTRA, "sxtra" },
	{ SYSZ_INS_TABORT, "tabort" },
	{ SYSZ_INS_TAM, "tam" },
	{ SYSZ_INS_TAR, "tar" },
	{ SYSZ_INS_TB, "tb" },
	{ SYSZ_INS_TBDR, "tbdr" },
	{ SYSZ_INS_TBEDR, "tbedr" },
	{ SYSZ_INS_TBEGIN, "tbegin" },
	{ SYSZ_INS_TBEGINC, "tbeginc" },
	{ SYSZ_INS_TCDB, "tcdb" },
	{ SYSZ_INS_TCEB, "tceb" },
	{ SYSZ_INS_TCXB, "tcxb" },
	{ SYSZ_INS_TDCDT, "tdcdt" },
	{ SYSZ_INS_TDCET, "tdcet" },
	{ SYSZ_INS_TDCXT, "tdcxt" },
	{ SYSZ_INS_TDGDT, "tdgdt" },
	{ SYSZ_INS_TDGET, "tdget" },
	{ SYSZ_INS_TDGXT, "tdgxt" },
	{ SYSZ_INS_TEND, "tend" },
	{ SYSZ_INS_THDER, "thder" },
	{ SYSZ_INS_THDR, "thdr" },
	{ SYSZ_INS_TP, "tp" },
	{ SYSZ_INS_TPI, "tpi" },
	{ SYSZ_INS_TPROT, "tprot" },
	{ SYSZ_INS_TR, "tr" },
	{ SYSZ_INS_TRACE, "trace" },
	{ SYSZ_INS_TRACG, "tracg" },
	{ SYSZ_INS_TRAP2, "trap2" },
	{ SYSZ_INS_TRAP4, "trap4" },
	{ SYSZ_INS_TRE, "tre" },
	{ SYSZ_INS_TROO, "troo" },
	{ SYSZ_INS_TROT, "trot" },
	{ SYSZ_INS_TRT, "trt" },
	{ SYSZ_INS_TRTE, "trte" },
	{ SYSZ_INS_TRTO, "trto" },
	{ SYSZ_INS_TRTR, "trtr" },
	{ SYSZ_INS_TRTRE, "trtre" },
	{ SYSZ_INS_TRTT, "trtt" },
	{ SYSZ_INS_TS, "ts" },
	{ SYSZ_INS_TSCH, "tsch" },
	{ SYSZ_INS_UNPK, "unpk" },
	{ SYSZ_INS_UNPKA, "unpka" },
	{ SYSZ_INS_UNPKU, "unpku" },
	{ SYSZ_INS_UPT, "upt" },
	{ SYSZ_INS_VA, "va" },
	{ SYSZ_INS_VAB, "vab" },
	{ SYSZ_INS_VAC, "vac" },
	{ SYSZ_INS_VACC, "vacc" },
	{ SYSZ_INS_VACCB, "vaccb" },
	{ SYSZ_INS_VACCC, "vaccc" },
	{ SYSZ_INS_VACCCQ, "vacccq" },
	{ SYSZ_INS_VACCF, "vaccf" },
	{ SYSZ_INS_VACCG, "vaccg" },
	{ SYSZ_INS_VACCH, "vacch" },
	{ SYSZ_INS_VACCQ, "vaccq" },
	{ SYSZ_INS_VACQ, "vacq" },
	{ SYSZ_INS_VAF, "vaf" },
	{ SYSZ_INS_VAG, "vag" },
	{ SYSZ_INS_VAH, "vah" },
	{ SYSZ_INS_VAP, "vap" },
	{ SYSZ_INS_VAQ, "vaq" },
	{ SYSZ_INS_VAVG, "vavg" },
	{ SYSZ_INS_VAVGB, "vavgb" },
	{ SYSZ_INS_VAVGF, "vavgf" },
	{ SYSZ_INS_VAVGG, "vavgg" },
	{ SYSZ_INS_VAVGH, "vavgh" },
	{ SYSZ_INS_VAVGL, "vavgl" },
	{ SYSZ_INS_VAVGLB, "vavglb" },
	{ SYSZ_INS_VAVGLF, "vavglf" },
	{ SYSZ_INS_VAVGLG, "vavglg" },
	{ SYSZ_INS_VAVGLH, "vavglh" },
	{ SYSZ_INS_VBPERM, "vbperm" },
	{ SYSZ_INS_VCDG, "vcdg" },
	{ SYSZ_INS_VCDGB, "vcdgb" },
	{ SYSZ_INS_VCDLG, "vcdlg" },
	{ SYSZ_INS_VCDLGB, "vcdlgb" },
	{ SYSZ_INS_VCEQ, "vceq" },
	{ SYSZ_INS_VCEQB, "vceqb" },
	{ SYSZ_INS_VCEQBS, "vceqbs" },
	{ SYSZ_INS_VCEQF, "vceqf" },
	{ SYSZ_INS_VCEQFS, "vceqfs" },
	{ SYSZ_INS_VCEQG, "vceqg" },
	{ SYSZ_INS_VCEQGS, "vceqgs" },
	{ SYSZ_INS_VCEQH, "vceqh" },
	{ SYSZ_INS_VCEQHS, "vceqhs" },
	{ SYSZ_INS_VCGD, "vcgd" },
	{ SYSZ_INS_VCGDB, "vcgdb" },
	{ SYSZ_INS_VCH, "vch" },
	{ SYSZ_INS_VCHB, "vchb" },
	{ SYSZ_INS_VCHBS, "vchbs" },
	{ SYSZ_INS_VCHF, "vchf" },
	{ SYSZ_INS_VCHFS, "vchfs" },
	{ SYSZ_INS_VCHG, "vchg" },
	{ SYSZ_INS_VCHGS, "vchgs" },
	{ SYSZ_INS_VCHH, "vchh" },
	{ SYSZ_INS_VCHHS, "vchhs" },
	{ SYSZ_INS_VCHL, "vchl" },
	{ SYSZ_INS_VCHLB, "vchlb" },
	{ SYSZ_INS_VCHLBS, "vchlbs" },
	{ SYSZ_INS_VCHLF, "vchlf" },
	{ SYSZ_INS_VCHLFS, "vchlfs" },
	{ SYSZ_INS_VCHLG, "vchlg" },
	{ SYSZ_INS_VCHLGS, "vchlgs" },
	{ SYSZ_INS_VCHLH, "vchlh" },
	{ SYSZ_INS_VCHLHS, "vchlhs" },
	{ SYSZ_INS_VCKSM, "vcksm" },
	{ SYSZ_INS_VCLGD, "vclgd" },
	{ SYSZ_INS_VCLGDB, "vclgdb" },
	{ SYSZ_INS_VCLZ, "vclz" },
	{ SYSZ_INS_VCLZB, "vclzb" },
	{ SYSZ_INS_VCLZF, "vclzf" },
	{ SYSZ_INS_VCLZG, "vclzg" },
	{ SYSZ_INS_VCLZH, "vclzh" },
	{ SYSZ_INS_VCP, "vcp" },
	{ SYSZ_INS_VCTZ, "vctz" },
	{ SYSZ_INS_VCTZB, "vctzb" },
	{ SYSZ_INS_VCTZF, "vctzf" },
	{ SYSZ_INS_VCTZG, "vctzg" },
	{ SYSZ_INS_VCTZH, "vctzh" },
	{ SYSZ_INS_VCVB, "vcvb" },
	{ SYSZ_INS_VCVBG, "vcvbg" },
	{ SYSZ_INS_VCVD, "vcvd" },
	{ SYSZ_INS_VCVDG, "vcvdg" },
	{ SYSZ_INS_VDP, "vdp" },
	{ SYSZ_INS_VEC, "vec" },
	{ SYSZ_INS_VECB, "vecb" },
	{ SYSZ_INS_VECF, "vecf" },
	{ SYSZ_INS_VECG, "vecg" },
	{ SYSZ_INS_VECH, "vech" },
	{ SYSZ_INS_VECL, "vecl" },
	{ SYSZ_INS_VECLB, "veclb" },
	{ SYSZ_INS_VECLF, "veclf" },
	{ SYSZ_INS_VECLG, "veclg" },
	{ SYSZ_INS_VECLH, "veclh" },
	{ SYSZ_INS_VERIM, "verim" },
	{ SYSZ_INS_VERIMB, "verimb" },
	{ SYSZ_INS_VERIMF, "verimf" },
	{ SYSZ_INS_VERIMG, "verimg" },
	{ SYSZ_INS_VERIMH, "verimh" },
	{ SYSZ_INS_VERLL, "verll" },
	{ SYSZ_INS_VERLLB, "verllb" },
	{ SYSZ_INS_VERLLF, "verllf" },
	{ SYSZ_INS_VERLLG, "verllg" },
	{ SYSZ_INS_VERLLH, "verllh" },
	{ SYSZ_INS_VERLLV, "verllv" },
	{ SYSZ_INS_VERLLVB, "verllvb" },
	{ SYSZ_INS_VERLLVF, "verllvf" },
	{ SYSZ_INS_VERLLVG, "verllvg" },
	{ SYSZ_INS_VERLLVH, "verllvh" },
	{ SYSZ_INS_VESL, "vesl" },
	{ SYSZ_INS_VESLB, "veslb" },
	{ SYSZ_INS_VESLF, "veslf" },
	{ SYSZ_INS_VESLG, "veslg" },
	{ SYSZ_INS_VESLH, "veslh" },
	{ SYSZ_INS_VESLV, "veslv" },
	{ SYSZ_INS_VESLVB, "veslvb" },
	{ SYSZ_INS_VESLVF, "veslvf" },
	{ SYSZ_INS_VESLVG, "veslvg" },
	{ SYSZ_INS_VESLVH, "veslvh" },
	{ SYSZ_INS_VESRA, "vesra" },
	{ SYSZ_INS_VESRAB, "vesrab" },
	{ SYSZ_INS_VESRAF, "vesraf" },
	{ SYSZ_INS_VESRAG, "vesrag" },
	{ SYSZ_INS_VESRAH, "vesrah" },
	{ SYSZ_INS_VESRAV, "vesrav" },
	{ SYSZ_INS_VESRAVB, "vesravb" },
	{ SYSZ_INS_VESRAVF, "vesravf" },
	{ SYSZ_INS_VESRAVG, "vesravg" },
	{ SYSZ_INS_VESRAVH, "vesravh" },
	{ SYSZ_INS_VESRL, "vesrl" },
	{ SYSZ_INS_VESRLB, "vesrlb" },
	{ SYSZ_INS_VESRLF, "vesrlf" },
	{ SYSZ_INS_VESRLG, "vesrlg" },
	{ SYSZ_INS_VESRLH, "vesrlh" },
	{ SYSZ_INS_VESRLV, "vesrlv" },
	{ SYSZ_INS_VESRLVB, "vesrlvb" },
	{ SYSZ_INS_VESRLVF, "vesrlvf" },
	{ SYSZ_INS_VESRLVG, "vesrlvg" },
	{ SYSZ_INS_VESRLVH, "vesrlvh" },
	{ SYSZ_INS_VFA, "vfa" },
	{ SYSZ_INS_VFADB, "vfadb" },
	{ SYSZ_INS_VFAE, "vfae" },
	{ SYSZ_INS_VFAEB, "vfaeb" },
	{ SYSZ_INS_VFAEBS, "vfaebs" },
	{ SYSZ_INS_VFAEF, "vfaef" },
	{ SYSZ_INS_VFAEFS, "vfaefs" },
	{ SYSZ_INS_VFAEH, "vfaeh" },
	{ SYSZ_INS_VFAEHS, "vfaehs" },
	{ SYSZ_INS_VFAEZB, "vfaezb" },
	{ SYSZ_INS_VFAEZBS, "vfaezbs" },
	{ SYSZ_INS_VFAEZF, "vfaezf" },
	{ SYSZ_INS_VFAEZFS, "vfaezfs" },
	{ SYSZ_INS_VFAEZH, "vfaezh" },
	{ SYSZ_INS_VFAEZHS, "vfaezhs" },
	{ SYSZ_INS_VFASB, "vfasb" },
	{ SYSZ_INS_VFCE, "vfce" },
	{ SYSZ_INS_VFCEDB, "vfcedb" },
	{ SYSZ_INS_VFCEDBS, "vfcedbs" },
	{ SYSZ_INS_VFCESB, "vfcesb" },
	{ SYSZ_INS_VFCESBS, "vfcesbs" },
	{ SYSZ_INS_VFCH, "vfch" },
	{ SYSZ_INS_VFCHDB, "vfchdb" },
	{ SYSZ_INS_VFCHDBS, "vfchdbs" },
	{ SYSZ_INS_VFCHE, "vfche" },
	{ SYSZ_INS_VFCHEDB, "vfchedb" },
	{ SYSZ_INS_VFCHEDBS, "vfchedbs" },
	{ SYSZ_INS_VFCHESB, "vfchesb" },
	{ SYSZ_INS_VFCHESBS, "vfchesbs" },
	{ SYSZ_INS_VFCHSB, "vfchsb" },
	{ SYSZ_INS_VFCHSBS, "vfchsbs" },
	{ SYSZ_INS_VFD, "vfd" },
	{ SYSZ_INS_VFDDB, "vfddb" },
	{ SYSZ_INS_VFDSB, "vfdsb" },
	{ SYSZ_INS_VFEE, "vfee" },
	{ SYSZ_INS_VFEEB, "vfeeb" },
	{ SYSZ_INS_VFEEBS, "vfeebs" },
	{ SYSZ_INS_VFEEF, "vfeef" },
	{ SYSZ_INS_VFEEFS, "vfeefs" },
	{ SYSZ_INS_VFEEH, "vfeeh" },
	{ SYSZ_INS_VFEEHS, "vfeehs" },
	{ SYSZ_INS_VFEEZB, "vfeezb" },
	{ SYSZ_INS_VFEEZBS, "vfeezbs" },
	{ SYSZ_INS_VFEEZF, "vfeezf" },
	{ SYSZ_INS_VFEEZFS, "vfeezfs" },
	{ SYSZ_INS_VFEEZH, "vfeezh" },
	{ SYSZ_INS_VFEEZHS, "vfeezhs" },
	{ SYSZ_INS_VFENE, "vfene" },
	{ SYSZ_INS_VFENEB, "vfeneb" },
	{ SYSZ_INS_VFENEBS, "vfenebs" },
	{ SYSZ_INS_VFENEF, "vfenef" },
	{ SYSZ_INS_VFENEFS, "vfenefs" },
	{ SYSZ_INS_VFENEH, "vfeneh" },
	{ SYSZ_INS_VFENEHS, "vfenehs" },
	{ SYSZ_INS_VFENEZB, "vfenezb" },
	{ SYSZ_INS_VFENEZBS, "vfenezbs" },
	{ SYSZ_INS_VFENEZF, "vfenezf" },
	{ SYSZ_INS_VFENEZFS, "vfenezfs" },
	{ SYSZ_INS_VFENEZH, "vfenezh" },
	{ SYSZ_INS_VFENEZHS, "vfenezhs" },
	{ SYSZ_INS_VFI, "vfi" },
	{ SYSZ_INS_VFIDB, "vfidb" },
	{ SYSZ_INS_VFISB, "vfisb" },
	{ SYSZ_INS_VFKEDB, "vfkedb" },
	{ SYSZ_INS_VFKEDBS, "vfkedbs" },
	{ SYSZ_INS_VFKESB, "vfkesb" },
	{ SYSZ_INS_VFKESBS, "vfkesbs" },
	{ SYSZ_INS_VFKHDB, "vfkhdb" },
	{ SYSZ_INS_VFKHDBS, "vfkhdbs" },
	{ SYSZ_INS_VFKHEDB, "vfkhedb" },
	{ SYSZ_INS_VFKHEDBS, "vfkhedbs" },
	{ SYSZ_INS_VFKHESB, "vfkhesb" },
	{ SYSZ_INS_VFKHESBS, "vfkhesbs" },
	{ SYSZ_INS_VFKHSB, "vfkhsb" },
	{ SYSZ_INS_VFKHSBS, "vfkhsbs" },
	{ SYSZ_INS_VFLCDB, "vflcdb" },
	{ SYSZ_INS_VFLCSB, "vflcsb" },
	{ SYSZ_INS_VFLL, "vfll" },
	{ SYSZ_INS_VFLLS, "vflls" },
	{ SYSZ_INS_VFLNDB, "vflndb" },
	{ SYSZ_INS_VFLNSB, "vflnsb" },
	{ SYSZ_INS_VFLPDB, "vflpdb" },
	{ SYSZ_INS_VFLPSB, "vflpsb" },
	{ SYSZ_INS_VFLR, "vflr" },
	{ SYSZ_INS_VFLRD, "vflrd" },
	{ SYSZ_INS_VFM, "vfm" },
	{ SYSZ_INS_VFMA, "vfma" },
	{ SYSZ_INS_VFMADB, "vfmadb" },
	{ SYSZ_INS_VFMASB, "vfmasb" },
	{ SYSZ_INS_VFMAX, "vfmax" },
	{ SYSZ_INS_VFMAXDB, "vfmaxdb" },
	{ SYSZ_INS_VFMAXSB, "vfmaxsb" },
	{ SYSZ_INS_VFMDB, "vfmdb" },
	{ SYSZ_INS_VFMIN, "vfmin" },
	{ SYSZ_INS_VFMINDB, "vfmindb" },
	{ SYSZ_INS_VFMINSB, "vfminsb" },
	{ SYSZ_INS_VFMS, "vfms" },
	{ SYSZ_INS_VFMSB, "vfmsb" },
	{ SYSZ_INS_VFMSDB, "vfmsdb" },
	{ SYSZ_INS_VFMSSB, "vfmssb" },
	{ SYSZ_INS_VFNMA, "vfnma" },
	{ SYSZ_INS_VFNMADB, "vfnmadb" },
	{ SYSZ_INS_VFNMASB, "vfnmasb" },
	{ SYSZ_INS_VFNMS, "vfnms" },
	{ SYSZ_INS_VFNMSDB, "vfnmsdb" },
	{ SYSZ_INS_VFNMSSB, "vfnmssb" },
	{ SYSZ_INS_VFPSO, "vfpso" },
	{ SYSZ_INS_VFPSODB, "vfpsodb" },
	{ SYSZ_INS_VFPSOSB, "vfpsosb" },
	{ SYSZ_INS_VFS, "vfs" },
	{ SYSZ_INS_VFSDB, "vfsdb" },
	{ SYSZ_INS_VFSQ, "vfsq" },
	{ SYSZ_INS_VFSQDB, "vfsqdb" },
	{ SYSZ_INS_VFSQSB, "vfsqsb" },
	{ SYSZ_INS_VFSSB, "vfssb" },
	{ SYSZ_INS_VFTCI, "vftci" },
	{ SYSZ_INS_VFTCIDB, "vftcidb" },
	{ SYSZ_INS_VFTCISB, "vftcisb" },
	{ SYSZ_INS_VGBM, "vgbm" },
	{ SYSZ_INS_VGEF, "vgef" },
	{ SYSZ_INS_VGEG, "vgeg" },
	{ SYSZ_INS_VGFM, "vgfm" },
	{ SYSZ_INS_VGFMA, "vgfma" },
	{ SYSZ_INS_VGFMAB, "vgfmab" },
	{ SYSZ_INS_VGFMAF, "vgfmaf" },
	{ SYSZ_INS_VGFMAG, "vgfmag" },
	{ SYSZ_INS_VGFMAH, "vgfmah" },
	{ SYSZ_INS_VGFMB, "vgfmb" },
	{ SYSZ_INS_VGFMF, "vgfmf" },
	{ SYSZ_INS_VGFMG, "vgfmg" },
	{ SYSZ_INS_VGFMH, "vgfmh" },
	{ SYSZ_INS_VGM, "vgm" },
	{ SYSZ_INS_VGMB, "vgmb" },
	{ SYSZ_INS_VGMF, "vgmf" },
	{ SYSZ_INS_VGMG, "vgmg" },
	{ SYSZ_INS_VGMH, "vgmh" },
	{ SYSZ_INS_VISTR, "vistr" },
	{ SYSZ_INS_VISTRB, "vistrb" },
	{ SYSZ_INS_VISTRBS, "vistrbs" },
	{ SYSZ_INS_VISTRF, "vistrf" },
	{ SYSZ_INS_VISTRFS, "vistrfs" },
	{ SYSZ_INS_VISTRH, "vistrh" },
	{ SYSZ_INS_VISTRHS, "vistrhs" },
	{ SYSZ_INS_VL, "vl" },
	{ SYSZ_INS_VLBB, "vlbb" },
	{ SYSZ_INS_VLC, "vlc" },
	{ SYSZ_INS_VLCB, "vlcb" },
	{ SYSZ_INS_VLCF, "vlcf" },
	{ SYSZ_INS_VLCG, "vlcg" },
	{ SYSZ_INS_VLCH, "vlch" },
	{ SYSZ_INS_VLDE, "vlde" },
	{ SYSZ_INS_VLDEB, "vldeb" },
	{ SYSZ_INS_VLEB, "vleb" },
	{ SYSZ_INS_VLED, "vled" },
	{ SYSZ_INS_VLEDB, "vledb" },
	{ SYSZ_INS_VLEF, "vlef" },
	{ SYSZ_INS_VLEG, "vleg" },
	{ SYSZ_INS_VLEH, "vleh" },
	{ SYSZ_INS_VLEIB, "vleib" },
	{ SYSZ_INS_VLEIF, "vleif" },
	{ SYSZ_INS_VLEIG, "vleig" },
	{ SYSZ_INS_VLEIH, "vleih" },
	{ SYSZ_INS_VLGV, "vlgv" },
	{ SYSZ_INS_VLGVB, "vlgvb" },
	{ SYSZ_INS_VLGVF, "vlgvf" },
	{ SYSZ_INS_VLGVG, "vlgvg" },
	{ SYSZ_INS_VLGVH, "vlgvh" },
	{ SYSZ_INS_VLIP, "vlip" },
	{ SYSZ_INS_VLL, "vll" },
	{ SYSZ_INS_VLLEZ, "vllez" },
	{ SYSZ_INS_VLLEZB, "vllezb" },
	{ SYSZ_INS_VLLEZF, "vllezf" },
	{ SYSZ_INS_VLLEZG, "vllezg" },
	{ SYSZ_INS_VLLEZH, "vllezh" },
	{ SYSZ_INS_VLLEZLF, "vllezlf" },
	{ SYSZ_INS_VLM, "vlm" },
	{ SYSZ_INS_VLP, "vlp" },
	{ SYSZ_INS_VLPB, "vlpb" },
	{ SYSZ_INS_VLPF, "vlpf" },
	{ SYSZ_INS_VLPG, "vlpg" },
	{ SYSZ_INS_VLPH, "vlph" },
	{ SYSZ_INS_VLR, "vlr" },
	{ SYSZ_INS_VLREP, "vlrep" },
	{ SYSZ_INS_VLREPB, "vlrepb" },
	{ SYSZ_INS_VLREPF, "vlrepf" },
	{ SYSZ_INS_VLREPG, "vlrepg" },
	{ SYSZ_INS_VLREPH, "vlreph" },
	{ SYSZ_INS_VLRL, "vlrl" },
	{ SYSZ_INS_VLRLR, "vlrlr" },
	{ SYSZ_INS_VLVG, "vlvg" },
	{ SYSZ_INS_VLVGB, "vlvgb" },
	{ SYSZ_INS_VLVGF, "vlvgf" },
	{ SYSZ_INS_VLVGG, "vlvgg" },
	{ SYSZ_INS_VLVGH, "vlvgh" },
	{ SYSZ_INS_VLVGP, "vlvgp" },
	{ SYSZ_INS_VMAE, "vmae" },
	{ SYSZ_INS_VMAEB, "vmaeb" },
	{ SYSZ_INS_VMAEF, "vmaef" },
	{ SYSZ_INS_VMAEH, "vmaeh" },
	{ SYSZ_INS_VMAH, "vmah" },
	{ SYSZ_INS_VMAHB, "vmahb" },
	{ SYSZ_INS_VMAHF, "vmahf" },
	{ SYSZ_INS_VMAHH, "vmahh" },
	{ SYSZ_INS_VMAL, "vmal" },
	{ SYSZ_INS_VMALB, "vmalb" },
	{ SYSZ_INS_VMALE, "vmale" },
	{ SYSZ_INS_VMALEB, "vmaleb" },
	{ SYSZ_INS_VMALEF, "vmalef" },
	{ SYSZ_INS_VMALEH, "vmaleh" },
	{ SYSZ_INS_VMALF, "vmalf" },
	{ SYSZ_INS_VMALH, "vmalh" },
	{ SYSZ_INS_VMALHB, "vmalhb" },
	{ SYSZ_INS_VMALHF, "vmalhf" },
	{ SYSZ_INS_VMALHH, "vmalhh" },
	{ SYSZ_INS_VMALHW, "vmalhw" },
	{ SYSZ_INS_VMALO, "vmalo" },
	{ SYSZ_INS_VMALOB, "vmalob" },
	{ SYSZ_INS_VMALOF, "vmalof" },
	{ SYSZ_INS_VMALOH, "vmaloh" },
	{ SYSZ_INS_VMAO, "vmao" },
	{ SYSZ_INS_VMAOB, "vmaob" },
	{ SYSZ_INS_VMAOF, "vmaof" },
	{ SYSZ_INS_VMAOH, "vmaoh" },
	{ SYSZ_INS_VME, "vme" },
	{ SYSZ_INS_VMEB, "vmeb" },
	{ SYSZ_INS_VMEF, "vmef" },
	{ SYSZ_INS_VMEH, "vmeh" },
	{ SYSZ_INS_VMH, "vmh" },
	{ SYSZ_INS_VMHB, "vmhb" },
	{ SYSZ_INS_VMHF, "vmhf" },
	{ SYSZ_INS_VMHH, "vmhh" },
	{ SYSZ_INS_VML, "vml" },
	{ SYSZ_INS_VMLB, "vmlb" },
	{ SYSZ_INS_VMLE, "vmle" },
	{ SYSZ_INS_VMLEB, "vmleb" },
	{ SYSZ_INS_VMLEF, "vmlef" },
	{ SYSZ_INS_VMLEH, "vmleh" },
	{ SYSZ_INS_VMLF, "vmlf" },
	{ SYSZ_INS_VMLH, "vmlh" },
	{ SYSZ_INS_VMLHB, "vmlhb" },
	{ SYSZ_INS_VMLHF, "vmlhf" },
	{ SYSZ_INS_VMLHH, "vmlhh" },
	{ SYSZ_INS_VMLHW, "vmlhw" },
	{ SYSZ_INS_VMLO, "vmlo" },
	{ SYSZ_INS_VMLOB, "vmlob" },
	{ SYSZ_INS_VMLOF, "vmlof" },
	{ SYSZ_INS_VMLOH, "vmloh" },
	{ SYSZ_INS_VMN, "vmn" },
	{ SYSZ_INS_VMNB, "vmnb" },
	{ SYSZ_INS_VMNF, "vmnf" },
	{ SYSZ_INS_VMNG, "vmng" },
	{ SYSZ_INS_VMNH, "vmnh" },
	{ SYSZ_INS_VMNL, "vmnl" },
	{ SYSZ_INS_VMNLB, "vmnlb" },
	{ SYSZ_INS_VMNLF, "vmnlf" },
	{ SYSZ_INS_VMNLG, "vmnlg" },
	{ SYSZ_INS_VMNLH, "vmnlh" },
	{ SYSZ_INS_VMO, "vmo" },
	{ SYSZ_INS_VMOB, "vmob" },
	{ SYSZ_INS_VMOF, "vmof" },
	{ SYSZ_INS_VMOH, "vmoh" },
	{ SYSZ_INS_VMP, "vmp" },
	{ SYSZ_INS_VMRH, "vmrh" },
	{ SYSZ_INS_VMRHB, "vmrhb" },
	{ SYSZ_INS_VMRHF, "vmrhf" },
	{ SYSZ_INS_VMRHG, "vmrhg" },
	{ SYSZ_INS_VMRHH, "vmrhh" },
	{ SYSZ_INS_VMRL, "vmrl" },
	{ SYSZ_INS_VMRLB, "vmrlb" },
	{ SYSZ_INS_VMRLF, "vmrlf" },
	{ SYSZ_INS_VMRLG, "vmrlg" },
	{ SYSZ_INS_VMRLH, "vmrlh" },
	{ SYSZ_INS_VMSL, "vmsl" },
	{ SYSZ_INS_VMSLG, "vmslg" },
	{ SYSZ_INS_VMSP, "vmsp" },
	{ SYSZ_INS_VMX, "vmx" },
	{ SYSZ_INS_VMXB, "vmxb" },
	{ SYSZ_INS_VMXF, "vmxf" },
	{ SYSZ_INS_VMXG, "vmxg" },
	{ SYSZ_INS_VMXH, "vmxh" },
	{ SYSZ_INS_VMXL, "vmxl" },
	{ SYSZ_INS_VMXLB, "vmxlb" },
	{ SYSZ_INS_VMXLF, "vmxlf" },
	{ SYSZ_INS_VMXLG, "vmxlg" },
	{ SYSZ_INS_VMXLH, "vmxlh" },
	{ SYSZ_INS_VN, "vn" },
	{ SYSZ_INS_VNC, "vnc" },
	{ SYSZ_INS_VNN, "vnn" },
	{ SYSZ_INS_VNO, "vno" },
	{ SYSZ_INS_VNX, "vnx" },
	{ SYSZ_INS_VO, "vo" },
	{ SYSZ_INS_VOC, "voc" },
	{ SYSZ_INS_VONE, "vone" },
	{ SYSZ_INS_VPDI, "vpdi" },
	{ SYSZ_INS_VPERM, "vperm" },
	{ SYSZ_INS_VPK, "vpk" },
	{ SYSZ_INS_VPKF, "vpkf" },
	{ SYSZ_INS_VPKG, "vpkg" },
	{ SYSZ_INS_VPKH, "vpkh" },
	{ SYSZ_INS_VPKLS, "vpkls" },
	{ SYSZ_INS_VPKLSF, "vpklsf" },
	{ SYSZ_INS_VPKLSFS, "vpklsfs" },
	{ SYSZ_INS_VPKLSG, "vpklsg" },
	{ SYSZ_INS_VPKLSGS, "vpklsgs" },
	{ SYSZ_INS_VPKLSH, "vpklsh" },
	{ SYSZ_INS_VPKLSHS, "vpklshs" },
	{ SYSZ_INS_VPKS, "vpks" },
	{ SYSZ_INS_VPKSF, "vpksf" },
	{ SYSZ_INS_VPKSFS, "vpksfs" },
	{ SYSZ_INS_VPKSG, "vpksg" },
	{ SYSZ_INS_VPKSGS, "vpksgs" },
	{ SYSZ_INS_VPKSH, "vpksh" },
	{ SYSZ_INS_VPKSHS, "vpkshs" },
	{ SYSZ_INS_VPKZ, "vpkz" },
	{ SYSZ_INS_VPOPCT, "vpopct" },
	{ SYSZ_INS_VPOPCTB, "vpopctb" },
	{ SYSZ_INS_VPOPCTF, "vpopctf" },
	{ SYSZ_INS_VPOPCTG, "vpopctg" },
	{ SYSZ_INS_VPOPCTH, "vpopcth" },
	{ SYSZ_INS_VPSOP, "vpsop" },
	{ SYSZ_INS_VREP, "vrep" },
	{ SYSZ_INS_VREPB, "vrepb" },
	{ SYSZ_INS_VREPF, "vrepf" },
	{ SYSZ_INS_VREPG, "vrepg" },
	{ SYSZ_INS_VREPH, "vreph" },
	{ SYSZ_INS_VREPI, "vrepi" },
	{ SYSZ_INS_VREPIB, "vrepib" },
	{ SYSZ_INS_VREPIF, "vrepif" },
	{ SYSZ_INS_VREPIG, "vrepig" },
	{ SYSZ_INS_VREPIH, "vrepih" },
	{ SYSZ_INS_VRP, "vrp" },
	{ SYSZ_INS_VS, "vs" },
	{ SYSZ_INS_VSB, "vsb" },
	{ SYSZ_INS_VSBCBI, "vsbcbi" },
	{ SYSZ_INS_VSBCBIQ, "vsbcbiq" },
	{ SYSZ_INS_VSBI, "vsbi" },
	{ SYSZ_INS_VSBIQ, "vsbiq" },
	{ SYSZ_INS_VSCBI, "vscbi" },
	{ SYSZ_INS_VSCBIB, "vscbib" },
	{ SYSZ_INS_VSCBIF, "vscbif" },
	{ SYSZ_INS_VSCBIG, "vscbig" },
	{ SYSZ_INS_VSCBIH, "vscbih" },
	{ SYSZ_INS_VSCBIQ, "vscbiq" },
	{ SYSZ_INS_VSCEF, "vscef" },
	{ SYSZ_INS_VSCEG, "vsceg" },
	{ SYSZ_INS_VSDP, "vsdp" },
	{ SYSZ_INS_VSEG, "vseg" },
	{ SYSZ_INS_VSEGB, "vsegb" },
	{ SYSZ_INS_VSEGF, "vsegf" },
	{ SYSZ_INS_VSEGH, "vsegh" },
	{ SYSZ_INS_VSEL, "vsel" },
	{ SYSZ_INS_VSF, "vsf" },
	{ SYSZ_INS_VSG, "vsg" },
	{ SYSZ_INS_VSH, "vsh" },
	{ SYSZ_INS_VSL, "vsl" },
	{ SYSZ_INS_VSLB, "vslb" },
	{ SYSZ_INS_VSLDB, "vsldb" },
	{ SYSZ_INS_VSP, "vsp" },
	{ SYSZ_INS_VSQ, "vsq" },
	{ SYSZ_INS_VSRA, "vsra" },
	{ SYSZ_INS_VSRAB, "vsrab" },
	{ SYSZ_INS_VSRL, "vsrl" },
	{ SYSZ_INS_VSRLB, "vsrlb" },
	{ SYSZ_INS_VSRP, "vsrp" },
	{ SYSZ_INS_VST, "vst" },
	{ SYSZ_INS_VSTEB, "vsteb" },
	{ SYSZ_INS_VSTEF, "vstef" },
	{ SYSZ_INS_VSTEG, "vsteg" },
	{ SYSZ_INS_VSTEH, "vsteh" },
	{ SYSZ_INS_VSTL, "vstl" },
	{ SYSZ_INS_VSTM, "vstm" },
	{ SYSZ_INS_VSTRC, "vstrc" },
	{ SYSZ_INS_VSTRCB, "vstrcb" },
	{ SYSZ_INS_VSTRCBS, "vstrcbs" },
	{ SYSZ_INS_VSTRCF, "vstrcf" },
	{ SYSZ_INS_VSTRCFS, "vstrcfs" },
	{ SYSZ_INS_VSTRCH, "vstrch" },
	{ SYSZ_INS_VSTRCHS, "vstrchs" },
	{ SYSZ_INS_VSTRCZB, "vstrczb" },
	{ SYSZ_INS_VSTRCZBS, "vstrczbs" },
	{ SYSZ_INS_VSTRCZF, "vstrczf" },
	{ SYSZ_INS_VSTRCZFS, "vstrczfs" },
	{ SYSZ_INS_VSTRCZH, "vstrczh" },
	{ SYSZ_INS_VSTRCZHS, "vstrczhs" },
	{ SYSZ_INS_VSTRL, "vstrl" },
	{ SYSZ_INS_VSTRLR, "vstrlr" },
	{ SYSZ_INS_VSUM, "vsum" },
	{ SYSZ_INS_VSUMB, "vsumb" },
	{ SYSZ_INS_VSUMG, "vsumg" },
	{ SYSZ_INS_VSUMGF, "vsumgf" },
	{ SYSZ_INS_VSUMGH, "vsumgh" },
	{ SYSZ_INS_VSUMH, "vsumh" },
	{ SYSZ_INS_VSUMQ, "vsumq" },
	{ SYSZ_INS_VSUMQF, "vsumqf" },
	{ SYSZ_INS_VSUMQG, "vsumqg" },
	{ SYSZ_INS_VTM, "vtm" },
	{ SYSZ_INS_VTP, "vtp" },
	{ SYSZ_INS_VUPH, "vuph" },
	{ SYSZ_INS_VUPHB, "vuphb" },
	{ SYSZ_INS_VUPHF, "vuphf" },
	{ SYSZ_INS_VUPHH, "vuphh" },
	{ SYSZ_INS_VUPKZ, "vupkz" },
	{ SYSZ_INS_VUPL, "vupl" },
	{ SYSZ_INS_VUPLB, "vuplb" },
	{ SYSZ_INS_VUPLF, "vuplf" },
	{ SYSZ_INS_VUPLH, "vuplh" },
	{ SYSZ_INS_VUPLHB, "vuplhb" },
	{ SYSZ_INS_VUPLHF, "vuplhf" },
	{ SYSZ_INS_VUPLHH, "vuplhh" },
	{ SYSZ_INS_VUPLHW, "vuplhw" },
	{ SYSZ_INS_VUPLL, "vupll" },
	{ SYSZ_INS_VUPLLB, "vupllb" },
	{ SYSZ_INS_VUPLLF, "vupllf" },
	{ SYSZ_INS_VUPLLH, "vupllh" },
	{ SYSZ_INS_VX, "vx" },
	{ SYSZ_INS_VZERO, "vzero" },
	{ SYSZ_INS_WCDGB, "wcdgb" },
	{ SYSZ_INS_WCDLGB, "wcdlgb" },
	{ SYSZ_INS_WCGDB, "wcgdb" },
	{ SYSZ_INS_WCLGDB, "wclgdb" },
	{ SYSZ_INS_WFADB, "wfadb" },
	{ SYSZ_INS_WFASB, "wfasb" },
	{ SYSZ_INS_WFAXB, "wfaxb" },
	{ SYSZ_INS_WFC, "wfc" },
	{ SYSZ_INS_WFCDB, "wfcdb" },
	{ SYSZ_INS_WFCEDB, "wfcedb" },
	{ SYSZ_INS_WFCEDBS, "wfcedbs" },
	{ SYSZ_INS_WFCESB, "wfcesb" },
	{ SYSZ_INS_WFCESBS, "wfcesbs" },
	{ SYSZ_INS_WFCEXB, "wfcexb" },
	{ SYSZ_INS_WFCEXBS, "wfcexbs" },
	{ SYSZ_INS_WFCHDB, "wfchdb" },
	{ SYSZ_INS_WFCHDBS, "wfchdbs" },
	{ SYSZ_INS_WFCHEDB, "wfchedb" },
	{ SYSZ_INS_WFCHEDBS, "wfchedbs" },
	{ SYSZ_INS_WFCHESB, "wfchesb" },
	{ SYSZ_INS_WFCHESBS, "wfchesbs" },
	{ SYSZ_INS_WFCHEXB, "wfchexb" },
	{ SYSZ_INS_WFCHEXBS, "wfchexbs" },
	{ SYSZ_INS_WFCHSB, "wfchsb" },
	{ SYSZ_INS_WFCHSBS, "wfchsbs" },
	{ SYSZ_INS_WFCHXB, "wfchxb" },
	{ SYSZ_INS_WFCHXBS, "wfchxbs" },
	{ SYSZ_INS_WFCSB, "wfcsb" },
	{ SYSZ_INS_WFCXB, "wfcxb" },
	{ SYSZ_INS_WFDDB, "wfddb" },
	{ SYSZ_INS_WFDSB, "wfdsb" },
	{ SYSZ_INS_WFDXB, "wfdxb" },
	{ SYSZ_INS_WFIDB, "wfidb" },
	{ SYSZ_INS_WFISB, "wfisb" },
	{ SYSZ_INS_WFIXB, "wfixb" },
	{ SYSZ_INS_WFK, "wfk" },
	{ SYSZ_INS_WFKDB, "wfkdb" },
	{ SYSZ_INS_WFKEDB, "wfkedb" },
	{ SYSZ_INS_WFKEDBS, "wfkedbs" },
	{ SYSZ_INS_WFKESB, "wfkesb" },
	{ SYSZ_INS_WFKESBS, "wfkesbs" },
	{ SYSZ_INS_WFKEXB, "wfkexb" },
	{ SYSZ_INS_WFKEXBS, "wfkexbs" },
	{ SYSZ_INS_WFKHDB, "wfkhdb" },
	{ SYSZ_INS_WFKHDBS, "wfkhdbs" },
	{ SYSZ_INS_WFKHEDB, "wfkhedb" },
	{ SYSZ_INS_WFKHEDBS, "wfkhedbs" },
	{ SYSZ_INS_WFKHESB, "wfkhesb" },
	{ SYSZ_INS_WFKHESBS, "wfkhesbs" },
	{ SYSZ_INS_WFKHEXB, "wfkhexb" },
	{ SYSZ_INS_WFKHEXBS, "wfkhexbs" },
	{ SYSZ_INS_WFKHSB, "wfkhsb" },
	{ SYSZ_INS_WFKHSBS, "wfkhsbs" },
	{ SYSZ_INS_WFKHXB, "wfkhxb" },
	{ SYSZ_INS_WFKHXBS, "wfkhxbs" },
	{ SYSZ_INS_WFKSB, "wfksb" },
	{ SYSZ_INS_WFKXB, "wfkxb" },
	{ SYSZ_INS_WFLCDB, "wflcdb" },
	{ SYSZ_INS_WFLCSB, "wflcsb" },
	{ SYSZ_INS_WFLCXB, "wflcxb" },
	{ SYSZ_INS_WFLLD, "wflld" },
	{ SYSZ_INS_WFLLS, "wflls" },
	{ SYSZ_INS_WFLNDB, "wflndb" },
	{ SYSZ_INS_WFLNSB, "wflnsb" },
	{ SYSZ_INS_WFLNXB, "wflnxb" },
	{ SYSZ_INS_WFLPDB, "wflpdb" },
	{ SYSZ_INS_WFLPSB, "wflpsb" },
	{ SYSZ_INS_WFLPXB, "wflpxb" },
	{ SYSZ_INS_WFLRD, "wflrd" },
	{ SYSZ_INS_WFLRX, "wflrx" },
	{ SYSZ_INS_WFMADB, "wfmadb" },
	{ SYSZ_INS_WFMASB, "wfmasb" },
	{ SYSZ_INS_WFMAXB, "wfmaxb" },
	{ SYSZ_INS_WFMAXDB, "wfmaxdb" },
	{ SYSZ_INS_WFMAXSB, "wfmaxsb" },
	{ SYSZ_INS_WFMAXXB, "wfmaxxb" },
	{ SYSZ_INS_WFMDB, "wfmdb" },
	{ SYSZ_INS_WFMINDB, "wfmindb" },
	{ SYSZ_INS_WFMINSB, "wfminsb" },
	{ SYSZ_INS_WFMINXB, "wfminxb" },
	{ SYSZ_INS_WFMSB, "wfmsb" },
	{ SYSZ_INS_WFMSDB, "wfmsdb" },
	{ SYSZ_INS_WFMSSB, "wfmssb" },
	{ SYSZ_INS_WFMSXB, "wfmsxb" },
	{ SYSZ_INS_WFMXB, "wfmxb" },
	{ SYSZ_INS_WFNMADB, "wfnmadb" },
	{ SYSZ_INS_WFNMASB, "wfnmasb" },
	{ SYSZ_INS_WFNMAXB, "wfnmaxb" },
	{ SYSZ_INS_WFNMSDB, "wfnmsdb" },
	{ SYSZ_INS_WFNMSSB, "wfnmssb" },
	{ SYSZ_INS_WFNMSXB, "wfnmsxb" },
	{ SYSZ_INS_WFPSODB, "wfpsodb" },
	{ SYSZ_INS_WFPSOSB, "wfpsosb" },
	{ SYSZ_INS_WFPSOXB, "wfpsoxb" },
	{ SYSZ_INS_WFSDB, "wfsdb" },
	{ SYSZ_INS_WFSQDB, "wfsqdb" },
	{ SYSZ_INS_WFSQSB, "wfsqsb" },
	{ SYSZ_INS_WFSQXB, "wfsqxb" },
	{ SYSZ_INS_WFSSB, "wfssb" },
	{ SYSZ_INS_WFSXB, "wfsxb" },
	{ SYSZ_INS_WFTCIDB, "wftcidb" },
	{ SYSZ_INS_WFTCISB, "wftcisb" },
	{ SYSZ_INS_WFTCIXB, "wftcixb" },
	{ SYSZ_INS_WLDEB, "wldeb" },
	{ SYSZ_INS_WLEDB, "wledb" },
	{ SYSZ_INS_XSCH, "xsch" },
	{ SYSZ_INS_ZAP, "zap" },
